@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,22 +18,15 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "defines.h"
+#include "config.h"
 #include "common.h"
-
+#include <arpa/inet.h>
+#include <netinet/in.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-/* required for inet_aton() */
 #include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-
-
-#ifdef DEBUG
-extern int debug;
-#endif
 
 static tcpr_cidr_t *cidr2cidr(char *);
 
@@ -41,7 +34,7 @@ static tcpr_cidr_t *cidr2cidr(char *);
  * prints to the given fd all the entries in mycidr
  */
 void
-print_cidr(tcpr_cidr_t * mycidr)
+print_cidr(tcpr_cidr_t *mycidr)
 {
     tcpr_cidr_t *cidr_ptr;
 
@@ -50,14 +43,12 @@ print_cidr(tcpr_cidr_t * mycidr)
     cidr_ptr = mycidr;
     while (cidr_ptr != NULL) {
         /* print it */
-        fprintf(stderr, "%s/%d, ", get_cidr2name(cidr_ptr, RESOLVE),
-                cidr_ptr->masklen);
+        fprintf(stderr, "%s/%d, ", get_cidr2name(cidr_ptr, RESOLVE), cidr_ptr->masklen);
 
         /* go to the next */
         if (cidr_ptr->next != NULL) {
             cidr_ptr = cidr_ptr->next;
-        }
-        else {
+        } else {
             break;
         }
     }
@@ -68,24 +59,21 @@ print_cidr(tcpr_cidr_t * mycidr)
  * deletes all entries in a cidr and destroys the datastructure
  */
 void
-destroy_cidr(tcpr_cidr_t * cidr)
+destroy_cidr(tcpr_cidr_t *cidr)
 {
-
     if (cidr != NULL) {
         if (cidr->next != NULL)
             destroy_cidr(cidr->next);
 
         safe_free(cidr);
     }
-    return;
-
 }
 
 /**
  * adds a new tcpr_cidr_t entry to cidrdata
  */
 void
-add_cidr(tcpr_cidr_t ** cidrdata, tcpr_cidr_t ** newcidr)
+add_cidr(tcpr_cidr_t **cidrdata, tcpr_cidr_t **newcidr)
 {
     tcpr_cidr_t *cidr_ptr;
     dbg(1, "Running new_cidr()");
@@ -102,30 +90,6 @@ add_cidr(tcpr_cidr_t ** cidrdata, tcpr_cidr_t ** newcidr)
     }
 }
 
-/**
- * takes in an IP and masklen, and returns a string in
- * cidr format: x.x.x.x/y.  This malloc's memory.
- */
-u_char *
-ip2cidr(const unsigned long ip, const int masklen)
-{
-    u_char *network;
-    char mask[32];
-
-    network = (u_char *)safe_malloc(20);
-
-    strlcpy((char *)network, (char *)get_addr2name4(ip, RESOLVE), 20);
-
-    strcat((char *)network, "/");
-    snprintf(mask, sizeof(mask), "%d", masklen);
-    if (masklen < 10)
-        strncat((char *)network, mask, 1);
-    else
-        strncat((char *)network, mask, 2);
-
-    return (network);
-}
-
 /**
  * Mallocs and sets to sane defaults a tcpr_cidr_t structure
  */
@@ -136,7 +100,7 @@ new_cidr(void)
     tcpr_cidr_t *newcidr;
 
     newcidr = (tcpr_cidr_t *)safe_malloc(sizeof(tcpr_cidr_t));
-    
+
     memset(newcidr, '\0', sizeof(tcpr_cidr_t));
     newcidr->masklen = 99;
     newcidr->next = NULL;
@@ -153,14 +117,13 @@ new_cidr_map(void)
     tcpr_cidrmap_t *new;
 
     new = (tcpr_cidrmap_t *)safe_malloc(sizeof(tcpr_cidrmap_t));
-    
+
     memset(new, '\0', sizeof(tcpr_cidrmap_t));
     new->next = NULL;
 
     return (new);
 }
 
-
 /**
  * Converts a single cidr (string) in the form of x.x.x.x/y into a
  * tcpr_cidr_t structure.  Will malloc the tcpr_cidr_t structure.
@@ -168,12 +131,12 @@ new_cidr_map(void)
 static tcpr_cidr_t *
 cidr2cidr(char *cidr)
 {
-    int count = 0;
-    unsigned int octets[4];     /* used in sscanf */
+    int count;
+    unsigned int octets[4]; /* used in sscanf */
     tcpr_cidr_t *newcidr;
     char networkip[16], tempoctet[4];
     int family;
-    char* p;
+    char *p;
 
     assert(cidr);
 
@@ -192,8 +155,7 @@ cidr2cidr(char *cidr)
      * scan it, and make sure it scanned correctly, also copy over the
      * masklen
      */
-    count = sscanf(cidr, "%u.%u.%u.%u/%d", &octets[0], &octets[1],
-        &octets[2], &octets[3], &newcidr->masklen);
+    count = sscanf(cidr, "%u.%u.%u.%u/%d", &octets[0], &octets[1], &octets[2], &octets[3], &newcidr->masklen);
 
     if (count == 4) {
         newcidr->masklen = 32;
@@ -215,7 +177,7 @@ cidr2cidr(char *cidr)
 
         /* skip past the opening [ */
         if (*cidr == '[')
-            cidr ++;
+            cidr++;
 
         if (get_name2addr6(cidr, RESOLVE, &newcidr->u.network6) > 0) {
             family = AF_INET6;
@@ -248,10 +210,8 @@ cidr2cidr(char *cidr)
 #elif HAVE_INET_ADDR
         newcidr->network = inet_addr(networkip);
 #endif
-    } else if (family == AF_INET6) {
-        /* Everything's done */
     } else {
-        goto error;
+        /* Everything's done */
     }
 
     newcidr->family = family;
@@ -260,20 +220,18 @@ cidr2cidr(char *cidr)
     /* we only get here on error parsing input */
 error:
     errx(-1, "%s: %s", "Unable to parse as a valid CIDR", cidr);
-    return NULL;
 }
 
-static void 
-mask_cidr6(char **cidrin, char* delim)
+static void
+mask_cidr6(char **cidrin, const char *delim)
 {
     if (**cidrin == '[' && *delim == ':') {
         char *p;
         ++*cidrin;
         /* make strtok happy */
         for (p = *cidrin; *p && *p != ']'; ++p) {
-            if (*p == ':') {
+            if (*p == ':')
                 *p = '#';
-            }
         }
     }
 }
@@ -285,9 +243,9 @@ mask_cidr6(char **cidrin, char* delim)
  * since we use strtok to process cidr, it gets zeroed out.
  */
 int
-parse_cidr(tcpr_cidr_t ** cidrdata, char *cidrin, char *delim)
+parse_cidr(tcpr_cidr_t **cidrdata, char *cidrin, char *delim)
 {
-    tcpr_cidr_t *cidr_ptr;             /* ptr to current cidr record */
+    tcpr_cidr_t *cidr_ptr; /* ptr to current cidr record */
     char *network;
     char *token = NULL;
 
@@ -295,6 +253,8 @@ parse_cidr(tcpr_cidr_t ** cidrdata, char *cidrin, char *delim)
 
     /* first iteration of input using strtok */
     network = strtok_r(cidrin, delim, &token);
+    if (network == NULL)
+        return 0;
 
     *cidrdata = cidr2cidr(network);
     cidr_ptr = *cidrdata;
@@ -313,8 +273,8 @@ parse_cidr(tcpr_cidr_t ** cidrdata, char *cidrin, char *delim)
         cidr_ptr->next = cidr2cidr(network);
         cidr_ptr = cidr_ptr->next;
     }
-    return 1;
 
+    return 1;
 }
 
 /**
@@ -324,7 +284,7 @@ parse_cidr(tcpr_cidr_t ** cidrdata, char *cidrin, char *delim)
  * since we use strtok to process optarg, it gets zeroed out
  */
 int
-parse_endpoints(tcpr_cidrmap_t ** cidrmap1, tcpr_cidrmap_t ** cidrmap2, const char *optarg)
+parse_endpoints(tcpr_cidrmap_t **cidrmap1, tcpr_cidrmap_t **cidrmap2, const char *optarg)
 {
 #define NEWMAP_LEN (INET6_ADDRSTRLEN * 2)
     char *map = NULL, newmap[NEWMAP_LEN];
@@ -341,13 +301,13 @@ parse_endpoints(tcpr_cidrmap_t ** cidrmap1, tcpr_cidrmap_t ** cidrmap2, const ch
         p = strstr(string, "]:[");
         if (!p)
             goto done;
-            
+
         *p = 0;
         strlcpy(newmap, "[::/0]:", NEWMAP_LEN);
         strlcat(newmap, string, NEWMAP_LEN);
         strlcat(newmap, "]", NEWMAP_LEN);
-        
-        if (! parse_cidr_map(cidrmap1, newmap))
+
+        if (!parse_cidr_map(cidrmap1, newmap))
             goto done;
 
         /* do again with the second IP */
@@ -355,29 +315,31 @@ parse_endpoints(tcpr_cidrmap_t ** cidrmap1, tcpr_cidrmap_t ** cidrmap2, const ch
         strlcpy(newmap, "[::/0]:", NEWMAP_LEN);
         strlcat(newmap, p + 2, NEWMAP_LEN);
 
-        if (! parse_cidr_map(cidrmap2, newmap))
+        if (!parse_cidr_map(cidrmap2, newmap))
             goto done;
 
     } else {
         /* ipv4 mode */
         memset(newmap, '\0', NEWMAP_LEN);
         map = strtok_r(string, ":", &token);
+        if (map == NULL)
+            goto done;
 
         strlcpy(newmap, "0.0.0.0/0:", NEWMAP_LEN);
         strlcat(newmap, map, NEWMAP_LEN);
-        if (! parse_cidr_map(cidrmap1, newmap))
+        if (!parse_cidr_map(cidrmap1, newmap))
             goto done;
-    
+
         /* do again with the second IP */
         memset(newmap, '\0', NEWMAP_LEN);
         map = strtok_r(NULL, ":", &token);
-    
+
         strlcpy(newmap, "0.0.0.0/0:", NEWMAP_LEN);
         strlcat(newmap, map, NEWMAP_LEN);
-        if (! parse_cidr_map(cidrmap2, newmap))
+        if (!parse_cidr_map(cidrmap2, newmap))
             goto done;
     }
-    
+
     /* success */
     res = 1;
 
@@ -386,7 +348,6 @@ done:
     return res;
 }
 
-
 /**
  * parses a list of tcpr_cidrmap_t's input from the user which should be in the form
  * of x.x.x.x/y:x.x.x.x/y,...
@@ -402,12 +363,12 @@ parse_cidr_map(tcpr_cidrmap_t **cidrmap, const char *optarg)
     char *token = NULL, *string;
     tcpr_cidrmap_t *ptr;
     int res = 0;
-    
+
     string = safe_strdup(optarg);
 
     /* first iteration */
     map = strtok_r(string, ",", &token);
-    if (! parse_cidr(&cidr, map, ":"))
+    if (!parse_cidr(&cidr, map, ":"))
         goto done;
 
     /* must return a linked list of two */
@@ -423,12 +384,12 @@ parse_cidr_map(tcpr_cidrmap_t **cidrmap, const char *optarg)
     ptr->from->next = NULL;
 
     /* do the same with the reset of the input */
-    while(1) {
+    while (1) {
         map = strtok_r(NULL, ",", &token);
         if (map == NULL)
             break;
 
-        if (! parse_cidr(&cidr, map, ":"))
+        if (!parse_cidr(&cidr, map, ":"))
             goto done;
 
         /* must return a linked list of two */
@@ -456,14 +417,14 @@ done:
  * returns 1 for true, 0 for false
  */
 int
-ip_in_cidr(const tcpr_cidr_t * mycidr, const unsigned long ip)
+ip_in_cidr(const tcpr_cidr_t *mycidr, const unsigned long ip)
 {
-    unsigned long ipaddr = 0, network = 0, mask = 0;
-    int ret = 0;
+    unsigned long ipaddr, network, mask;
+    int ret;
 #ifdef DEBUG
     char netstr[20];
 #endif
-    
+
     if (mycidr->family != AF_INET)
         return 0;
 
@@ -471,7 +432,7 @@ ip_in_cidr(const tcpr_cidr_t * mycidr, const unsigned long ip)
     if (mycidr->masklen == 0 && mycidr->u.network == 0)
         return 1;
 
-    mask = ~0;                  /* turn on all the bits */
+    mask = ~0; /* turn on all the bits */
 
     /* shift over by the correct number of bits */
     mask = mask << (32 - mycidr->masklen);
@@ -481,7 +442,6 @@ ip_in_cidr(const tcpr_cidr_t * mycidr, const unsigned long ip)
 
     network = htonl(mycidr->u.network) & mask;
 
-
 #ifdef DEBUG
     /* copy this for debug purposes, since it's not re-entrant */
     strlcpy(netstr, get_addr2name4(mycidr->u.network, RESOLVE), 20);
@@ -490,32 +450,29 @@ ip_in_cidr(const tcpr_cidr_t * mycidr, const unsigned long ip)
     /* if they're the same, then ip is in network */
     if (network == ipaddr) {
 #ifdef DEBUG
-        dbgx(1, "The ip %s is inside of %s/%d",
-            get_addr2name4(ip, RESOLVE), netstr, mycidr->masklen);
+        dbgx(1, "The ip %s is inside of %s/%d", get_addr2name4(ip, RESOLVE), netstr, mycidr->masklen);
 #endif
         ret = 1;
     } else {
 #ifdef DEBUG
-        dbgx(1, "The ip %s is not inside of %s/%d",
-            get_addr2name4(ip, RESOLVE), netstr, mycidr->masklen);
+        dbgx(1, "The ip %s is not inside of %s/%d", get_addr2name4(ip, RESOLVE), netstr, mycidr->masklen);
 #endif
         ret = 0;
     }
     return ret;
-
 }
 
 static int
 ip6_addr_is_unspec(const struct tcpr_in6_addr *addr)
 {
-    return addr->tcpr_s6_addr32[0] == 0 && addr->tcpr_s6_addr32[1] == 0 &&
-      addr->tcpr_s6_addr32[2] == 0 && addr->tcpr_s6_addr32[3] == 0;
+    return addr->tcpr_s6_addr32[0] == 0 && addr->tcpr_s6_addr32[1] == 0 && addr->tcpr_s6_addr32[2] == 0 &&
+           addr->tcpr_s6_addr32[3] == 0;
 }
 
 int
-ip6_in_cidr(const tcpr_cidr_t * mycidr, const struct tcpr_in6_addr *addr)
+ip6_in_cidr(const tcpr_cidr_t *mycidr, const struct tcpr_in6_addr *addr)
 {
-    int ret = 0;
+    int ret;
 #ifdef DEBUG
     char netstr[INET6_ADDRSTRLEN];
 #endif
@@ -536,7 +493,7 @@ ip6_in_cidr(const tcpr_cidr_t * mycidr, const struct tcpr_in6_addr *addr)
             goto out;
         }
     }
-    
+
     if ((k = mycidr->masklen % 8) == 0) {
         ret = 1;
         goto out;
@@ -556,47 +513,42 @@ out:
     /* if they're the same, then ip is in network */
     if (ret) {
 #ifdef DEBUG
-        dbgx(1, "The ip %s is inside of %s/%d",
-            get_addr2name6(addr, RESOLVE), netstr, mycidr->masklen);
+        dbgx(1, "The ip %s is inside of %s/%d", get_addr2name6(addr, RESOLVE), netstr, mycidr->masklen);
 #endif
     } else {
 #ifdef DEBUG
-        dbgx(1, "The ip %s is not inside of %s/%d",
-            get_addr2name6(addr, RESOLVE), netstr, mycidr->masklen);
+        dbgx(1, "The ip %s is not inside of %s/%d", get_addr2name6(addr, RESOLVE), netstr, mycidr->masklen);
 #endif
     }
     return ret;
-
 }
 
-
 /**
  * iterates over cidrdata to find if a given ip matches
  * returns 1 for true, 0 for false
  */
 
 int
-check_ip_cidr(tcpr_cidr_t * cidrdata, const unsigned long ip)
+check_ip_cidr(tcpr_cidr_t *cidrdata, const unsigned long ip)
 {
     tcpr_cidr_t *mycidr;
 
-    /* if we have no cidrdata, of course it isn't in there 
+    /* if we have no cidrdata, of course it isn't in there
      * this actually should happen occasionally, so don't put an assert here
      */
     if (cidrdata == NULL)
         return 1;
-        
+
     mycidr = cidrdata;
 
     /* loop through cidr */
     while (1) {
-
         /* if match, return 1 */
         if (ip_in_cidr(mycidr, ip)) {
             dbgx(3, "Found %s in cidr", get_addr2name4(ip, RESOLVE));
             return 1;
         }
-        
+
         /* check for next record */
         if (mycidr->next != NULL) {
             mycidr = mycidr->next;
@@ -611,7 +563,7 @@ check_ip_cidr(tcpr_cidr_t * cidrdata, const unsigned long ip)
 }
 
 int
-check_ip6_cidr(tcpr_cidr_t * cidrdata, const struct tcpr_in6_addr *addr)
+check_ip6_cidr(tcpr_cidr_t *cidrdata, const struct tcpr_in6_addr *addr)
 {
     tcpr_cidr_t *mycidr;
 
@@ -626,13 +578,12 @@ check_ip6_cidr(tcpr_cidr_t * cidrdata, const struct tcpr_in6_addr *addr)
 
     /* loop through cidr */
     while (1) {
-
         /* if match, return 1 */
         if (ip6_in_cidr(mycidr, addr)) {
             dbgx(3, "Found %s in cidr", get_addr2name6(addr, RESOLVE));
             return 1;
         }
-        
+
         /* check for next record */
         if (mycidr->next != NULL) {
             mycidr = mycidr->next;
@@ -645,55 +596,3 @@ check_ip6_cidr(tcpr_cidr_t * cidrdata, const struct tcpr_in6_addr *addr)
     dbgx(3, "Didn't find %s in cidr", get_addr2name6(addr, RESOLVE));
     return 0;
 }
-
-
-/**
- * cidr2ip takes a tcpr_cidr_t and a delimiter
- * and returns a string which lists all the IP addresses in the cidr
- * deliminated by the given char
- */
-char *
-cidr2iplist(tcpr_cidr_t * cidr, char delim)
-{
-    char *list = NULL;
-    char ipaddr[18], tempbuff[20];
-    u_int32_t size, addr, first, last, numips;
-    struct in_addr in;
-    int i;
-
-    /* 
-     * 16 bytes per IP + delim
-     * # of IP's = 2^(32-masklen)
-     */
-    numips = 2;
-    for (i = 2; i <= (32 - cidr->masklen); i++)
-        numips *= 2;
-
-    size = 17 * numips - 1;
-
-    list = (char *)safe_malloc(size);
-
-    memset(list, 0, size);
-
-    /* first and last should not include network or broadcast */
-    first = ntohl(cidr->u.network) + 1;
-    last = first + numips - 3;
-
-    dbgx(1, "First: %u\t\tLast: %u", first, last);
-
-    /* loop through all but the last one */
-    for (addr = first; addr < last; addr++) {
-        in.s_addr = htonl(addr);
-        snprintf(tempbuff, 17, "%s%c", inet_ntoa(in), delim);
-        memcpy(ipaddr, tempbuff, 16);
-        dbgx(2, "%s", ipaddr);
-        strlcat(list, ipaddr, size);
-    }
-
-    /* last is a special case, end in \0 */
-    in.s_addr = htonl(addr);
-    snprintf(ipaddr, 17, "%s", inet_ntoa(in));
-    strlcat(list, ipaddr, size);
-
-    return list;
-}
