@@ -18,11 +18,11 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __MAC_H__
-#define __MAC_H__
+#pragma once
+
+#include "cache.h"
+#include "defines.h"
 
 void mac2hex(const char *mac, u_char *dst, int len);
 int dualmac2hex(const char *dualmac, u_char *first, u_char *second, int len);
 tcpr_dir_t macinstring(const char *macstring, const u_char *mac);
-
-#endif /* __MAC_H__ */
