@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,11 +18,10 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _PCAP_DLT_H_
-#define _PCAP_DLT_H_
+#pragma once
 
 /*
- * Cisco HDLC.  Used by Dag interfaces for SONET 
+ * Cisco HDLC.  Used by Dag interfaces for SONET
  * and possibly others
  */
 
@@ -33,8 +32,3 @@ struct hdlc_hdr_s {
     u_int16_t protocol;
 };
 typedef struct hdlc_hdr_s hdlc_hdr_t;
-
-
-#endif /* _PCAP_DLT_H_ */
-
-
