@@ -33,18 +33,17 @@
 
 #ifdef HAVE_TX_RING
 
+#include "txring.h"
 #include "err.h"
 #include "utils.h"
-#include "txring.h"
-#include <unistd.h>
+#include <errno.h>
 #include <string.h>
 #include <sys/mman.h>
-#include <errno.h>
+#include <unistd.h>
 
 volatile int shutdown_flag = 0;
 int tdata_offset = TPACKET_HDRLEN - sizeof(struct sockaddr_ll);
 
-
 /**
  * This task will call send() procedure
  */
@@ -57,67 +56,65 @@ txring_send(void *arg)
 
     do {
         /* send all buffers with TP_STATUS_SEND_REQUEST */
-        ec_send=sendto(fd_socket, NULL, 0, MSG_DONTWAIT,
-                (struct sockaddr *)NULL, sizeof(struct sockaddr_ll));
+        ec_send = sendto(fd_socket, NULL, 0, MSG_DONTWAIT, (struct sockaddr *)NULL, sizeof(struct sockaddr_ll));
 
         if (ec_send > 0) {
             total += ec_send;
             dbgx(2, "Sent %d bytes (+%d bytes)", total, ec_send);
-        } else  {
+        } else {
             /* nothing to do => schedule : useful if no SMP */
             usleep(100);
         }
 
-
     } while (!shutdown_flag);
 
-    //if(blocking) printf("end of task send()\n");
-    //printf("end of task send(ec=%x)\n", ec_send);
+    // if(blocking) printf("end of task send()\n");
+    // printf("end of task send(ec=%x)\n", ec_send);
 
-    return (void*) ec_send;
+    return (void *)ec_send;
 }
 
 /**
  * Put data in TX ring buffer and rotate it if necessary
  */
 int
-txring_put(txring_t *txp, const void * data, size_t length)
+txring_put(txring_t *txp, const void *data, size_t length)
 {
     struct tpacket_hdr *ps_header;
-    char * to_data;
+    char *to_data;
     int loop = 1;
     int first_loop = 1;
     unsigned int start_index = txp->tx_index;
 
     do {
-        ps_header = ((struct tpacket_hdr *)((void *)txp->tx_head + 
-                    (txp->treq->tp_frame_size * txp->tx_index)));
-        to_data = ((void*) ps_header) + tdata_offset;
+        ps_header = ((struct tpacket_hdr *)((void *)txp->tx_head + (txp->treq->tp_frame_size * txp->tx_index)));
+        to_data = ((void *)ps_header) + tdata_offset;
 
         switch ((volatile uint32_t)ps_header->tp_status) {
-            case TP_STATUS_WRONG_FORMAT:
-                warnx("TP_STATUS_WRONG_FORMAT occuries O_o. Frame %d, pkt len %d\n", 
-                        txp->tx_index, length);
-                break;
+        case TP_STATUS_WRONG_FORMAT:
+            warnx("TP_STATUS_WRONG_FORMAT occuries O_o. Frame %d, pkt len %d\n", txp->tx_index, length);
+            break;
 
-            case TP_STATUS_AVAILABLE:
-                if (length > txp->treq->tp_frame_size) {
-                    //TODO Fragment packet
-                    warnx("[!] %d bytes from %d packet truncated\n",
-                            length-txp->treq->tp_frame_size, length);
-                    length = txp->treq->tp_frame_size;
-                }
-                memcpy(to_data, data, length);
-                ps_header->tp_len = length;
-                ps_header->tp_status = TP_STATUS_SEND_REQUEST;
-                loop = 0;
-                break;
+        case TP_STATUS_AVAILABLE:
+            if (length > txp->treq->tp_frame_size) {
+                // TODO Fragment packet
+                warnx("[!] %d bytes from %d packet truncated\n", length - txp->treq->tp_frame_size, length);
+                length = txp->treq->tp_frame_size;
+            }
+            memcpy(to_data, data, length);
+            ps_header->tp_len = length;
+            ps_header->tp_status = TP_STATUS_SEND_REQUEST;
+            loop = 0;
+            break;
 
-            default:
-                dbgx(2,"TPACKET status %u at frame %d with length %d\n",
-                        ps_header->tp_status, txp->tx_index, ps_header->tp_len);
-                usleep(0);
-                break;
+        default:
+            dbgx(2,
+                 "TPACKET status %u at frame %d with length %d\n",
+                 ps_header->tp_status,
+                 txp->tx_index,
+                 ps_header->tp_len);
+            usleep(0);
+            break;
         }
         txp->tx_index++;
 
@@ -131,24 +128,23 @@ txring_put(txring_t *txp, const void * data, size_t length)
             errno = ENOBUFS;
             return -1;
         }
-    } while(loop == 1);
+    } while (loop == 1);
 
     return ps_header->tp_len;
 }
 
-
 /**
  * \brief Build TX ring buffer request structure
  *
  * This builds a ring buffer request structure making sure
  * that we have buffers big enough so that a frame which
  * is the size of the MTU doesn't get truncated. We also
- * need to structure things with minimum memory wastage 
+ * need to structure things with minimum memory wastage
  */
 void
-txring_mkreq(struct tpacket_req* treq, unsigned int mtu)
+txring_mkreq(struct tpacket_req *treq, unsigned int mtu)
 {
-    unsigned int pg,bs;
+    unsigned int pg, bs;
     unsigned int s;
     unsigned int mult = 1;
     unsigned nr_blocks = 1000;
@@ -158,27 +154,30 @@ txring_mkreq(struct tpacket_req* treq, unsigned int mtu)
 
     memset(treq, 0, sizeof(struct tpacket_req));
     if (bs <= s) {
-        while(bs < s) {
+        while (bs < s) {
             bs += pg;
             mult++;
         }
 
         treq->tp_block_size = bs;
         treq->tp_frame_size = bs / mult;
-        treq->tp_block_nr   = nr_blocks;
-        treq->tp_frame_nr   = mult * nr_blocks;
+        treq->tp_block_nr = nr_blocks;
+        treq->tp_frame_nr = mult * nr_blocks;
     } else {
-        while ((s * (mult + 1)) <=pg) {
+        while ((s * (mult + 1)) <= pg) {
             mult++;
         }
         treq->tp_block_size = pg;
         treq->tp_frame_size = pg / mult;
-        treq->tp_block_nr   = nr_blocks;
-        treq->tp_frame_nr   = mult * nr_blocks;
+        treq->tp_block_nr = nr_blocks;
+        treq->tp_frame_nr = mult * nr_blocks;
     }
-    dbgx(1, "txring: block_size=%d block_nr=%d frame_size=%d frame_nr=%d", 
-            treq->tp_block_size, treq->tp_block_nr, treq->tp_frame_size, 
-            treq->tp_frame_nr);
+    dbgx(1,
+         "txring: block_size=%d block_nr=%d frame_size=%d frame_nr=%d",
+         treq->tp_block_size,
+         treq->tp_block_nr,
+         treq->tp_frame_size,
+         treq->tp_frame_nr);
 }
 
 /**
@@ -203,22 +202,19 @@ txring_init(int fd, unsigned int mtu)
     txp->tx_index = 0; /* Set index on start*/
 
     /* Set PACKET_LOSS sockoption */
-    if (setsockopt(fd, SOL_PACKET, PACKET_LOSS, (char *)&mode_loss,
-                sizeof(mode_loss)) < 0) {
+    if (setsockopt(fd, SOL_PACKET, PACKET_LOSS, (char *)&mode_loss, sizeof(mode_loss)) < 0) {
         perror("setsockopt: PACKET_LOSS");
         return NULL;
     }
 
     /* Enable TX Ring */
-    if (setsockopt(fd, SOL_PACKET, PACKET_TX_RING, (char *)txp->treq,
-                sizeof(struct tpacket_req)) < 0) {
+    if (setsockopt(fd, SOL_PACKET, PACKET_TX_RING, (char *)txp->treq, sizeof(struct tpacket_req)) < 0) {
         perror("Can't setsockopt PACKET_TX_RING");
         return NULL;
     }
 
-
     /* mmap unswapped memory with TX ring buffer*/
-    txp->tx_head = mmap(0, txp->tx_size, PROT_READ|PROT_WRITE, MAP_SHARED, fd, 0);
+    txp->tx_head = mmap(0, txp->tx_size, PROT_READ | PROT_WRITE, MAP_SHARED, fd, 0);
     if (txp->tx_head == MAP_FAILED) {
         perror("mmap() failed ");
         return NULL;
