@@ -399,55 +399,62 @@
 */
 
 #if 0
-#define TestProg    20000          /* Generate built-in test program
-                     if defined.  The value specifies
-                     how many buffer allocation attempts
-                     the test program should make. */
+#define TestProg                                                                                                       \
+    20000 /* Generate built-in test program                                                                            \
+if defined.  The value specifies                                                                                       \
+how many buffer allocation attempts                                                                                    \
+the test program should make. */
 #endif
-#define SizeQuant   4              /* Buffer allocation size quantum:
-                     all buffers allocated are a
-                     multiple of this size.  This
-                     MUST be a power of two. */
+#define SizeQuant                                                                                                      \
+    4 /* Buffer allocation size quantum:                                                                               \
+all buffers allocated are a                                                                                            \
+multiple of this size.  This                                                                                           \
+MUST be a power of two. */
 #if 0
-#define BufDump     1              /* Define this symbol to enable the
-                     bpoold() function which dumps the
-                     buffers in a buffer pool. */
+#define BufDump                                                                                                        \
+    1 /* Define this symbol to enable the                                                                              \
+bpoold() function which dumps the                                                                                      \
+buffers in a buffer pool. */
 
-#define BufValid    1              /* Define this symbol to enable the
-                     bpoolv() function for validating
-                     a buffer pool. */
+#define BufValid                                                                                                       \
+    1 /* Define this symbol to enable the                                                                              \
+bpoolv() function for validating                                                                                       \
+a buffer pool. */
 
-#define DumpData    1              /* Define this symbol to enable the
-                     bufdump() function which allows
-                     dumping the contents of an allocated
-                     or free buffer. */
+#define DumpData                                                                                                       \
+    1 /* Define this symbol to enable the                                                                              \
+bufdump() function which allows                                                                                        \
+dumping the contents of an allocated                                                                                   \
+or free buffer. */
 
-#define BufStats    1              /* Define this symbol to enable the
-                     bstats() function which calculates
-                     the total free space in the buffer
-                     pool, the largest available
-                     buffer, and the total space
-                     currently allocated. */
+#define BufStats                                                                                                       \
+    1 /* Define this symbol to enable the                                                                              \
+bstats() function which calculates                                                                                     \
+the total free space in the buffer                                                                                     \
+pool, the largest available                                                                                            \
+buffer, and the total space                                                                                            \
+currently allocated. */
 
-#define FreeWipe    1              /* Wipe free buffers to a guaranteed
-                     pattern of garbage to trip up
-                     miscreants who attempt to use
-                     pointers into released buffers. */
+#define FreeWipe                                                                                                       \
+    1 /* Wipe free buffers to a guaranteed                                                                             \
+pattern of garbage to trip up                                                                                          \
+miscreants who attempt to use                                                                                          \
+pointers into released buffers. */
 
-#define BestFit     1              /* Use a best fit algorithm when
-                     searching for space for an
-                     allocation request.  This uses
-                     memory more efficiently, but
-                     allocation will be much slower. */
+#define BestFit                                                                                                        \
+    1 /* Use a best fit algorithm when                                                                                 \
+searching for space for an                                                                                             \
+allocation request.  This uses                                                                                         \
+memory more efficiently, but                                                                                           \
+allocation will be much slower. */
 #endif
-#define BECtl        1              /* Define this symbol to enable the
-                     bectl() function for automatic
-                     pool space control.  */
-
-#include <stdio.h>
+#define BECtl                                                                                                          \
+    1 /* Define this symbol to enable the                                                                              \
+bectl() function for automatic                                                                                         \
+pool space control.  */
 
 #ifdef lint
-#define NDEBUG                  /* Exits in asserts confuse lint */
+#define NDEBUG /* Exits in asserts confuse lint */
 /* LINTLIBRARY */                     /* Don't complain about def, no ref */
 extern char *sprintf();               /* Sun includes don't define sprintf */
 #endif
@@ -455,9 +462,9 @@ extern char *sprintf();               /* Sun includes don't define sprintf */
 #include <assert.h>
 #include <memory.h>
 
-#ifdef BufDump                  /* BufDump implies DumpData */
+#ifdef BufDump /* BufDump implies DumpData */
 #ifndef DumpData
-#define DumpData    1
+#define DumpData 1
 #endif
 #endif
 
@@ -470,48 +477,47 @@ extern char *sprintf();               /* Sun includes don't define sprintf */
 
 #include "bget.h"
 
-#define MemSize     int           /* Type for size arguments to memxxx()
-                     functions such as memcmp(). */
+#define MemSize                                                                                                        \
+    int /* Type for size arguments to memxxx()                                                                         \
+functions such as memcmp(). */
 
 /* Queue links */
 
 struct qlinks {
-    struct bfhead *flink;          /* Forward link */
-    struct bfhead *blink;          /* Backward link */
+    struct bfhead *flink; /* Forward link */
+    struct bfhead *blink; /* Backward link */
 };
 
 /* Header in allocated and free buffers */
 
 struct bhead {
-    bufsize prevfree;              /* Relative link back to previous
-                     free buffer in memory or 0 if
-                     previous buffer is allocated.    */
-    bufsize bsize;              /* Buffer size: positive if free,
-                     negative if allocated. */
+    bufsize prevfree; /* Relative link back to previous
+        free buffer in memory or 0 if
+        previous buffer is allocated.    */
+    bufsize bsize;    /* Buffer size: positive if free,
+           negative if allocated. */
 };
-#define BH(p)    ((struct bhead *) (p))
+#define BH(p) ((struct bhead *)(p))
 
 /*  Header in directly allocated buffers (by acqfcn) */
 
 struct bdhead {
-    bufsize tsize;              /* Total size, including overhead */
-    struct bhead bh;              /* Common header */
+    bufsize tsize;   /* Total size, including overhead */
+    struct bhead bh; /* Common header */
 };
-#define BDH(p)    ((struct bdhead *) (p))
+#define BDH(p) ((struct bdhead *)(p))
 
 /* Header in free buffers */
 
 struct bfhead {
-    struct bhead bh;              /* Common allocated/free header */
-    struct qlinks ql;              /* Links on free list */
-};
-#define BFH(p)    ((struct bfhead *) (p))
-
-static struct bfhead freelist = {     /* List of free buffers */
-    {0, 0},
-    {&freelist, &freelist}
+    struct bhead bh;  /* Common allocated/free header */
+    struct qlinks ql; /* Links on free list */
 };
+#define BFH(p) ((struct bfhead *)(p))
 
+static struct bfhead freelist = {/* List of free buffers */
+                                 {0, 0},
+                                 {&freelist, &freelist}};
 
 #ifdef BufStats
 static bufsize totalloc = 0;          /* Total space currently allocated */
@@ -542,20 +548,21 @@ static bufsize pool_len = 0;          /*  0: no bpool calls have been made
 
 /*  Minimum allocation quantum: */
 
-#define QLSize    (sizeof(struct qlinks))
-#define SizeQ    ((SizeQuant > QLSize) ? SizeQuant : QLSize)
+#define QLSize (sizeof(struct qlinks))
+#define SizeQ ((SizeQuant > QLSize) ? SizeQuant : QLSize)
 
-#define V   (void)              /* To denote unwanted returned values */
+#define V (void)/* To denote unwanted returned values */
 
 /* End sentinel: value placed in bsize field of dummy block delimiting
    end of pool block.  The most negative number which will  fit  in  a
    bufsize, defined in a way that the compiler will accept. */
 
-#define ESent    ((bufsize) (-(((1L << (sizeof(bufsize) * 8 - 2)) - 1) * 2) - 2))
+#define ESent ((bufsize)(-(((1L << (sizeof(bufsize) * 8 - 2)) - 1) * 2) - 2))
 
 /*  BGET  --  Allocate a buffer.  */
 
-void *bget(requested_size)
+void *
+bget(requested_size)
 bufsize requested_size;
 {
     bufsize size = requested_size;
@@ -570,8 +577,8 @@ bufsize requested_size;
 
     assert(size > 0);
 
-    if (size < (bufsize)SizeQ) {           /* Need at least room for the */
-        size = SizeQ;              /*    queue links.  */
+    if (size < (bufsize)SizeQ) { /* Need at least room for the */
+        size = SizeQ;            /*    queue links.  */
     }
 #ifdef SizeQuant
 #if SizeQuant > 1
@@ -579,9 +586,9 @@ bufsize requested_size;
 #endif
 #endif
 
-    size += sizeof(struct bhead);     /* Add overhead in allocated buffer
-                                       * to size required.
-                                       */
+    size += sizeof(struct bhead); /* Add overhead in allocated buffer
+                                   * to size required.
+                                   */
 
 #ifdef BECtl
     /* If a compact function was provided in the call to bectl(), wrap
@@ -591,14 +598,13 @@ bufsize requested_size;
 
     while (1) {
 #endif
-        b = freelist.ql.flink;
+    b = freelist.ql.flink;
 #ifdef BestFit
         best = &freelist;
 #endif
 
-
-        /* Scan the free list searching for the first buffer big enough
-       to hold the requested size buffer. */
+    /* Scan the free list searching for the first buffer big enough
+   to hold the requested size buffer. */
 
 #ifdef BestFit
         while (b != &freelist) {
@@ -612,74 +618,73 @@ bufsize requested_size;
         b = best;
 #endif /* BestFit */
 
-        while (b != &freelist) {
-            if ((bufsize) b->bh.bsize >= size) {
+    while (b != &freelist) {
+        if ((bufsize)b->bh.bsize >= size) {
+            /* Buffer  is big enough to satisfy  the request.  Allocate it
+             * to the caller.  We must decide whether the buffer is  large
+             * enough  to  split  into  the part given to the caller and a
+             * free buffer that remains on the free list, or  whether  the
+             * entire  buffer  should  be  removed from the free list and
+             * given to the caller in its entirety.  We  only  split  the
+             * buffer if enough room remains for a header plus the minimum
+             * quantum of allocation.
+             */
 
-                /* Buffer  is big enough to satisfy  the request.  Allocate it
-                 * to the caller.  We must decide whether the buffer is  large
-                 * enough  to  split  into  the part given to the caller and a
-                 * free buffer that remains on the free list, or  whether  the
-                 * entire  buffer  should  be  removed from the free list and
-                 * given to the caller in its entirety.  We  only  split  the
-                 * buffer if enough room remains for a header plus the minimum
-                 * quantum of allocation.
-                 */
+            if ((b->bh.bsize - size) > (bufsize)(SizeQ + (sizeof(struct bhead)))) {
+                struct bhead *ba, *bn;
 
-                if ((b->bh.bsize - size) > (bufsize)(SizeQ + (sizeof(struct bhead)))) {
-                    struct bhead *ba, *bn;
-
-                    ba = BH(((char *) b) + (b->bh.bsize - size));
-                    bn = BH(((char *) ba) + size);
-                    assert(bn->prevfree == b->bh.bsize);
-                    /* Subtract size from length of free block. */
-                    b->bh.bsize -= size;
-                    /* Link allocated buffer to the previous free buffer. */
-                    ba->prevfree = b->bh.bsize;
-                    /* Plug negative size into user buffer. */
-                    ba->bsize = -(bufsize) size;
-                    /* Mark buffer after this one not preceded by free block. */
-                    bn->prevfree = 0;
+                ba = BH(((char *)b) + (b->bh.bsize - size));
+                bn = BH(((char *)ba) + size);
+                assert(bn->prevfree == b->bh.bsize);
+                /* Subtract size from length of free block. */
+                b->bh.bsize -= size;
+                /* Link allocated buffer to the previous free buffer. */
+                ba->prevfree = b->bh.bsize;
+                /* Plug negative size into user buffer. */
+                ba->bsize = -(bufsize)size;
+                /* Mark buffer after this one not preceded by free block. */
+                bn->prevfree = 0;
 
 #ifdef BufStats
                     totalloc += size;
                     numget++;          /* Increment number of bget() calls */
 #endif
-                    buf = (void *) ((((char *) ba) + sizeof(struct bhead)));
-                    return buf;
-                } else {
-                    struct bhead *ba;
+                buf = (void *)((((char *)ba) + sizeof(struct bhead)));
+                return buf;
+            } else {
+                struct bhead *ba;
 
-                    ba = BH(((char *) b) + b->bh.bsize);
-                    assert(ba->prevfree == b->bh.bsize);
+                ba = BH(((char *)b) + b->bh.bsize);
+                assert(ba->prevfree == b->bh.bsize);
 
-                    /* The buffer isn't big enough to split.  Give  the  whole
-                     * shebang to the caller and remove it from the free list.
-                     */
+                /* The buffer isn't big enough to split.  Give  the  whole
+                 * shebang to the caller and remove it from the free list.
+                 */
 
-                    assert(b->ql.blink->ql.flink == b);
-                    assert(b->ql.flink->ql.blink == b);
-                    b->ql.blink->ql.flink = b->ql.flink;
-                    b->ql.flink->ql.blink = b->ql.blink;
+                assert(b->ql.blink->ql.flink == b);
+                assert(b->ql.flink->ql.blink == b);
+                b->ql.blink->ql.flink = b->ql.flink;
+                b->ql.flink->ql.blink = b->ql.blink;
 
 #ifdef BufStats
                     totalloc += b->bh.bsize;
                     numget++;          /* Increment number of bget() calls */
 #endif
-                    /* Negate size to mark buffer allocated. */
-                    b->bh.bsize = -(b->bh.bsize);
+                /* Negate size to mark buffer allocated. */
+                b->bh.bsize = -(b->bh.bsize);
 
-                    /* Zero the back pointer in the next buffer in memory
-                     * to indicate that this buffer is allocated.
-                     */
-                    ba->prevfree = 0;
+                /* Zero the back pointer in the next buffer in memory
+                 * to indicate that this buffer is allocated.
+                 */
+                ba->prevfree = 0;
 
-                    /* Give user buffer starting at queue links. */
-                    buf =  (void *) &(b->ql);
-                    return buf;
-                }
+                /* Give user buffer starting at queue links. */
+                buf = (void *)&(b->ql);
+                return buf;
             }
-            b = b->ql.flink;          /* Link to next buffer */
         }
+        b = b->ql.flink; /* Link to next buffer */
+    }
 #ifdef BECtl
 
         /* We failed to find a buffer.  If there's a compact  function
@@ -749,29 +754,30 @@ bufsize requested_size;
            the  entire  contents  of  the buffer to zero, not just the
            region requested by the caller. */
 
-void *bgetz(size)
-  bufsize size;
+void *
+bgetz(size)
+bufsize size;
 {
-    char *buf = (char *) bget(size);
+    char *buf = (char *)bget(size);
 
     if (buf != NULL) {
-    struct bhead *b;
-    bufsize rsize;
+        struct bhead *b;
+        bufsize rsize;
 
-    b = BH(buf - sizeof(struct bhead));
-    rsize = -(b->bsize);
-    if (rsize == 0) {
-        struct bdhead *bd;
+        b = BH(buf - sizeof(struct bhead));
+        rsize = -(b->bsize);
+        if (rsize == 0) {
+            struct bdhead *bd;
 
-        bd = BDH(buf - sizeof(struct bdhead));
-        rsize = bd->tsize - sizeof(struct bdhead);
-    } else {
-        rsize -= sizeof(struct bhead);
+            bd = BDH(buf - sizeof(struct bdhead));
+            rsize = bd->tsize - sizeof(struct bdhead);
+        } else {
+            rsize -= sizeof(struct bhead);
+        }
+        assert(rsize >= size);
+        V memset(buf, 0, (MemSize)rsize);
     }
-    assert(rsize >= size);
-    V memset(buf, 0, (MemSize) rsize);
-    }
-    return ((void *) buf);
+    return ((void *)buf);
 }
 
 /*  BGETR  --  Reallocate a buffer.  This is a minimal implementation,
@@ -779,12 +785,11 @@ void *bgetz(size)
            enhanced to allow the buffer to grow into adjacent free
            blocks and to avoid moving data unnecessarily.  */
 
-void *bgetr(buf, size)
-  void *buf;
-  bufsize size;
+void *bgetr(buf, size) void *buf;
+bufsize size;
 {
     void *nbuf;
-    bufsize osize;              /* Old size of buffer */
+    bufsize osize; /* Old size of buffer */
     struct bhead *b;
 
     if ((nbuf = bget(size)) == NULL) { /* Acquire new buffer */
@@ -793,7 +798,7 @@ void *bgetr(buf, size)
     if (buf == NULL) {
         return nbuf;
     }
-    b = BH(((char *) buf) - sizeof(struct bhead));
+    b = BH(((char *)buf) - sizeof(struct bhead));
     osize = -b->bsize;
 #ifdef BECtl
     if (osize == 0) {
@@ -804,10 +809,11 @@ void *bgetr(buf, size)
         osize = bd->tsize - sizeof(struct bdhead);
     } else
 #endif
-        osize -= sizeof(struct bhead);
+    osize -= sizeof(struct bhead);
     assert(osize > 0);
-    V memcpy((char *) nbuf, (char *) buf, /* Copy the data */
-            (MemSize) ((size < osize) ? size : osize));
+    V memcpy((char *)nbuf,
+             (char *)buf, /* Copy the data */
+             (MemSize)((size < osize) ? size : osize));
 
     brel(buf);
     return nbuf;
@@ -815,13 +821,12 @@ void *bgetr(buf, size)
 
 /*  BREL  --  Release a buffer.  */
 
-void brel(buf)
-  void *buf;
+void brel(buf) void *buf;
 {
     struct bfhead *b, *bn;
 
     assert(buf != NULL);
-    b = BFH(((char *) buf) - sizeof(struct bhead));
+    b = BFH(((char *)buf) - sizeof(struct bhead));
 #ifdef BufStats
     numrel++;                  /* Increment number of brel() calls */
 #endif
@@ -851,14 +856,14 @@ void brel(buf)
        allocated. */
 
     if (b->bh.bsize >= 0) {
-    bn = NULL;
+        bn = NULL;
     }
     assert(b->bh.bsize < 0);
 
     /*    Back pointer in next buffer must be zero, indicating the
     same thing: */
 
-    assert(BH((char *) b - b->bh.bsize)->prevfree == 0);
+    assert(BH((char *)b - b->bh.bsize)->prevfree == 0);
 
 #ifdef BufStats
     totalloc += b->bh.bsize;
@@ -868,31 +873,29 @@ void brel(buf)
     /* If the back link is nonzero, the previous buffer is free.  */
 
     if (b->bh.prevfree != 0) {
+        /* The previous buffer is free.  Consolidate this buffer  with    it
+           by  adding  the  length  of    this  buffer  to the previous free
+           buffer.  Note that we subtract the size  in    the  buffer  being
+               released,  since  it's  negative to indicate that the buffer is
+           allocated. */
 
-    /* The previous buffer is free.  Consolidate this buffer  with    it
-       by  adding  the  length  of    this  buffer  to the previous free
-       buffer.  Note that we subtract the size  in    the  buffer  being
-           released,  since  it's  negative to indicate that the buffer is
-       allocated. */
-
-    register bufsize size = b->bh.bsize;
+        register bufsize size = b->bh.bsize;
 
         /* Make the previous buffer the one we're working on. */
-    assert(BH((char *) b - b->bh.prevfree)->bsize == b->bh.prevfree);
-    b = BFH(((char *) b) - b->bh.prevfree);
-    b->bh.bsize -= size;
+        assert(BH((char *)b - b->bh.prevfree)->bsize == b->bh.prevfree);
+        b = BFH(((char *)b) - b->bh.prevfree);
+        b->bh.bsize -= size;
     } else {
-
         /* The previous buffer isn't allocated.  Insert this buffer
        on the free list as an isolated free block. */
 
-    assert(freelist.ql.blink->ql.flink == &freelist);
-    assert(freelist.ql.flink->ql.blink == &freelist);
-    b->ql.flink = &freelist;
-    b->ql.blink = freelist.ql.blink;
-    freelist.ql.blink = b;
-    b->ql.blink->ql.flink = b;
-    b->bh.bsize = -b->bh.bsize;
+        assert(freelist.ql.blink->ql.flink == &freelist);
+        assert(freelist.ql.flink->ql.blink == &freelist);
+        b->ql.flink = &freelist;
+        b->ql.blink = freelist.ql.blink;
+        freelist.ql.blink = b;
+        b->ql.blink->ql.flink = b;
+        b->bh.bsize = -b->bh.bsize;
     }
 
     /* Now we look at the next buffer in memory, located by advancing from
@@ -900,27 +903,26 @@ void brel(buf)
        free.  If it is, we combine  this  buffer  with    the  next  one    in
        memory, dechaining the second buffer from the free list. */
 
-    bn =  BFH(((char *) b) + b->bh.bsize);
+    bn = BFH(((char *)b) + b->bh.bsize);
     if (bn->bh.bsize > 0) {
+        /* The buffer is free.    Remove it from the free list and add
+           its size to that of our buffer. */
 
-    /* The buffer is free.    Remove it from the free list and add
-       its size to that of our buffer. */
+        assert(BH((char *)bn + bn->bh.bsize)->prevfree == bn->bh.bsize);
+        assert(bn->ql.blink->ql.flink == bn);
+        assert(bn->ql.flink->ql.blink == bn);
+        bn->ql.blink->ql.flink = bn->ql.flink;
+        bn->ql.flink->ql.blink = bn->ql.blink;
+        b->bh.bsize += bn->bh.bsize;
 
-    assert(BH((char *) bn + bn->bh.bsize)->prevfree == bn->bh.bsize);
-    assert(bn->ql.blink->ql.flink == bn);
-    assert(bn->ql.flink->ql.blink == bn);
-    bn->ql.blink->ql.flink = bn->ql.flink;
-    bn->ql.flink->ql.blink = bn->ql.blink;
-    b->bh.bsize += bn->bh.bsize;
+        /* Finally,  advance  to   the    buffer    that   follows    the  newly
+           consolidated free block.  We must set its  backpointer  to  the
+           head  of  the  consolidated free block.  We know the next block
+           must be an allocated block because the process of recombination
+           guarantees  that  two  free    blocks will never be contiguous in
+           memory.  */
 
-    /* Finally,  advance  to   the    buffer    that   follows    the  newly
-       consolidated free block.  We must set its  backpointer  to  the
-       head  of  the  consolidated free block.  We know the next block
-       must be an allocated block because the process of recombination
-       guarantees  that  two  free    blocks will never be contiguous in
-       memory.  */
-
-    bn = BFH(((char *) b) + b->bh.bsize);
+        bn = BFH(((char *)b) + b->bh.bsize);
     }
 #ifdef FreeWipe
     V memset(((char *) b) + sizeof(struct bfhead), 0x55,
@@ -979,9 +981,8 @@ void bectl(compact, acquire, release, pool_incr)
 
 /*  BPOOL  --  Add a region of memory to the buffer pool.  */
 
-void bpool(buf, len)
-  void *buf;
-  bufsize len;
+void bpool(buf, len) void *buf;
+bufsize len;
 {
     struct bfhead *b = BFH(buf);
     struct bhead *bn;
@@ -1006,7 +1007,7 @@ void bpool(buf, len)
        it  had    better    not  be  (much) larger than the largest buffer
        whose size we can store in bhead.bsize. */
 
-    assert(len - sizeof(struct bhead) <= -((bufsize) ESent + 1));
+    assert(len - sizeof(struct bhead) <= -((bufsize)ESent + 1));
 
     /* Clear  the  backpointer at  the start of the block to indicate that
        there  is  no  free  block  prior  to  this   one.    That   blocks
@@ -1032,13 +1033,13 @@ void bpool(buf, len)
        allocation and release functions). */
 
     len -= sizeof(struct bhead);
-    b->bh.bsize = (bufsize) len;
+    b->bh.bsize = (bufsize)len;
 #ifdef FreeWipe
     V memset(((char *) b) + sizeof(struct bfhead), 0x55,
          (MemSize) (len - sizeof(struct bfhead)));
 #endif
-    bn = BH(((char *) b) + len);
-    bn->prevfree = (bufsize) len;
+    bn = BH(((char *)b) + len);
+    bn->prevfree = (bufsize)len;
     /* Definition of ESent assumes two's complement! */
     assert((~0) == -1);
     bn->bsize = ESent;
@@ -1245,34 +1246,34 @@ int bpoolv(buf)
 }
 #endif /* BufValid */
 
-        /***********************\
-    *            *
-    * Built-in test program *
-    *            *
-        \***********************/
+/***********************\
+*            *
+* Built-in test program *
+*            *
+\***********************/
 
 #ifdef TestProg
 
-#define Repeatable  1              /* Repeatable pseudorandom sequence */
+#define Repeatable 1 /* Repeatable pseudorandom sequence */
                       /* If Repeatable is not defined, a
                      time-seeded pseudorandom sequence
                      is generated, exercising BGET with
                      a different pattern of calls on each
                      run. */
-#define OUR_RAND              /* Use our own built-in version of
-                     rand() to guarantee the test is
-                     100% repeatable. */
+#define OUR_RAND     /* Use our own built-in version of                                                                \
+            rand() to guarantee the test is                                                                            \
+            100% repeatable. */
 
 #ifdef BECtl
-#define PoolSize    300000          /* Test buffer pool size */
+#define PoolSize 300000 /* Test buffer pool size */
 #else
-#define PoolSize    50000          /* Test buffer pool size */
+#define PoolSize 50000 /* Test buffer pool size */
 #endif
-#define ExpIncr     32768          /* Test expansion block size */
-#define CompactTries 10           /* Maximum tries at compacting */
+#define ExpIncr 32768   /* Test expansion block size */
+#define CompactTries 10 /* Maximum tries at compacting */
 
-#define dumpAlloc   0              /* Dump allocated buffers ? */
-#define dumpFree    0              /* Dump free buffers ? */
+#define dumpAlloc 0 /* Dump allocated buffers ? */
+#define dumpFree 0  /* Dump free buffers ? */
 
 #ifndef Repeatable
 extern long time();
