@@ -7,25 +7,23 @@
  */
 
 #include "config.h"
-
+#include "mod.h"
+#include "pkt.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include "mod.h"
-#include "pkt.h"
-
 #ifndef INET6_ADDRSTRLEN
 #define INET6_ADDRSTRLEN 46
 #endif
 
-#define EXTRACT_16BITS(p)    ((uint16_t)ntohs(*(uint16_t *)(p)))
-#define EXTRACT_32BITS(p)    ((uint32_t)ntohl(*(uint32_t *)(p)))
+#define EXTRACT_16BITS(p) ((uint16_t)ntohs(*(uint16_t *)(p)))
+#define EXTRACT_32BITS(p) ((uint32_t)ntohl(*(uint32_t *)(p)))
 
 /* XXX - _print_* routines adapted from tcpdump */
 
 static void
-_print_icmp(u_char *p, _U_ int length)
+print_icmp(u_char *p, _U_ int length)
 {
     struct ip_hdr *ip;
     struct icmp_hdr *icmp;
@@ -39,7 +37,7 @@ _print_icmp(u_char *p, _U_ int length)
 }
 
 static void
-_print_icmp6(u_char *p, _U_ int length)
+print_icmp6(u_char *p, _U_ int length)
 {
     struct ip6_hdr *ip6;
     struct icmp_hdr *icmp;
@@ -53,7 +51,7 @@ _print_icmp6(u_char *p, _U_ int length)
 }
 
 void
-_print_tcp(int family, unsigned char *p, int length)
+print_tcp(int family, unsigned char *p, int length)
 {
     struct tcp_hdr *tcp;
     u_short sport, dport, win, urp;
@@ -64,21 +62,21 @@ _print_tcp(int family, unsigned char *p, int length)
     char src[INET6_ADDRSTRLEN], dst[INET6_ADDRSTRLEN];
 
     if (family == AF_INET6) {
-            struct ip6_hdr *ip6 = (struct ip6_hdr *)p;
-            tcp = (struct tcp_hdr *)(p + IP6_HDR_LEN);
-            len = length;
+        struct ip6_hdr *ip6 = (struct ip6_hdr *)p;
+        tcp = (struct tcp_hdr *)(p + IP6_HDR_LEN);
+        len = length;
 
-            ip6_ntop(&ip6->ip6_src, src, sizeof(src));
-            ip6_ntop(&ip6->ip6_dst, dst, sizeof(dst));
+        ip6_ntop(&ip6->ip6_src, src, sizeof(src));
+        ip6_ntop(&ip6->ip6_dst, dst, sizeof(dst));
     } else {
-            struct ip_hdr *ip;
+        struct ip_hdr *ip;
 
-    ip = (struct ip_hdr *)p;
-    tcp = (struct tcp_hdr *)(p + (ip->ip_hl * 4));
-    len = length - (ip->ip_hl * 4);
+        ip = (struct ip_hdr *)p;
+        tcp = (struct tcp_hdr *)(p + (ip->ip_hl * 4));
+        len = length - (ip->ip_hl * 4);
 
-            ip_ntop(&ip->ip_src, src, sizeof(src));
-            ip_ntop(&ip->ip_dst, dst, sizeof(dst));
+        ip_ntop(&ip->ip_src, src, sizeof(src));
+        ip_ntop(&ip->ip_dst, dst, sizeof(dst));
     }
 
     if (len < TCP_HDR_LEN) {
@@ -95,11 +93,15 @@ _print_tcp(int family, unsigned char *p, int length)
 
     printf("%s.%d > %s.%d: ", src, sport, dst, dport);
 
-    if (tcp->th_flags & (TH_SYN|TH_FIN|TH_RST|TH_PUSH)) {
-        if (tcp->th_flags & TH_SYN)    putchar('S');
-        if (tcp->th_flags & TH_FIN)    putchar('F');
-        if (tcp->th_flags & TH_RST)    putchar('R');
-        if (tcp->th_flags & TH_PUSH)    putchar('P');
+    if (tcp->th_flags & (TH_SYN | TH_FIN | TH_RST | TH_PUSH)) {
+        if (tcp->th_flags & TH_SYN)
+            putchar('S');
+        if (tcp->th_flags & TH_FIN)
+            putchar('F');
+        if (tcp->th_flags & TH_RST)
+            putchar('R');
+        if (tcp->th_flags & TH_PUSH)
+            putchar('P');
     } else
         putchar('.');
 
@@ -133,16 +135,20 @@ _print_tcp(int family, unsigned char *p, int length)
             if (TCP_OPT_TYPEONLY(opt)) {
                 len = 1;
             } else {
-                len = *cp++;    /* total including type, len */
+                len = *cp++; /* total including type, len */
                 if (len < 2 || len > tcp_hl)
                     goto bad;
-                --tcp_hl;         /* account for length byte */
+                --tcp_hl; /* account for length byte */
             }
-            --tcp_hl;           /* account for type byte */
+            --tcp_hl; /* account for type byte */
             datalen = 0;
 
 /* Bail if "l" bytes of data are not left or were not captured  */
-#define LENCHECK(l) { if ((l) > tcp_hl) goto bad; }
+#define LENCHECK(l)                                                                                                    \
+    {                                                                                                                  \
+        if ((l) > tcp_hl)                                                                                              \
+            goto bad;                                                                                                  \
+    }
 
             switch (opt) {
             case TCP_OPT_MSS:
@@ -170,8 +176,7 @@ _print_tcp(int family, unsigned char *p, int length)
                 break;
             case TCP_OPT_SACK:
                 datalen = len - 2;
-                if ((datalen % 8) != 0 ||
-                    !(tcp->th_flags & TH_ACK)) {
+                if ((datalen % 8) != 0 || !(tcp->th_flags & TH_ACK)) {
                     printf("malformed sack ");
                     printf("[len %d] ", datalen);
                     break;
@@ -230,9 +235,9 @@ _print_tcp(int family, unsigned char *p, int length)
             tcp_hl -= datalen;
 
             /* Check specification against observed length */
-            ++datalen;                /* option octet */
+            ++datalen; /* option octet */
             if (!TCP_OPT_TYPEONLY(opt))
-                ++datalen;              /* size octet */
+                ++datalen; /* size octet */
             if (datalen != len)
                 printf("[len %d]", len);
             ch = ',';
@@ -242,7 +247,7 @@ _print_tcp(int family, unsigned char *p, int length)
         putchar('>');
     }
     return;
- bad:
+bad:
     fputs("[bad opt]", stdout);
     if (ch != '\0')
         putchar('>');
@@ -250,35 +255,34 @@ _print_tcp(int family, unsigned char *p, int length)
 }
 
 static void
-_print_udp(int family, u_char *p, _U_ int length)
+print_udp(int family, u_char *p, _U_ int length)
 {
     struct udp_hdr *udp;
     char src[INET6_ADDRSTRLEN], dst[INET6_ADDRSTRLEN];
 
     if (family == AF_INET6) {
-            struct ip6_hdr *ip6 = (struct ip6_hdr *)p;
-            udp = (struct udp_hdr *)(p + IP6_HDR_LEN);
+        struct ip6_hdr *ip6 = (struct ip6_hdr *)p;
+        udp = (struct udp_hdr *)(p + IP6_HDR_LEN);
 
-            ip6_ntop(&ip6->ip6_src, src, sizeof(src));
-            ip6_ntop(&ip6->ip6_dst, dst, sizeof(dst));
+        ip6_ntop(&ip6->ip6_src, src, sizeof(src));
+        ip6_ntop(&ip6->ip6_dst, dst, sizeof(dst));
     } else {
-            struct ip_hdr *ip;
+        struct ip_hdr *ip;
 
-    ip = (struct ip_hdr *)p;
-    udp = (struct udp_hdr *)(p + (ip->ip_hl * 4));
+        ip = (struct ip_hdr *)p;
+        udp = (struct udp_hdr *)(p + (ip->ip_hl * 4));
 
-            ip_ntop(&ip->ip_src, src, sizeof(src));
-            ip_ntop(&ip->ip_dst, dst, sizeof(dst));
+        ip_ntop(&ip->ip_src, src, sizeof(src));
+        ip_ntop(&ip->ip_dst, dst, sizeof(dst));
     }
 
     /* XXX - truncation? */
-    printf("%s.%d > %s.%d:", src, ntohs(udp->uh_sport),
-        dst, ntohs(udp->uh_dport));
+    printf("%s.%d > %s.%d:", src, ntohs(udp->uh_sport), dst, ntohs(udp->uh_dport));
     printf(" udp %d", ntohs(udp->uh_ulen) - UDP_HDR_LEN);
 }
 
 static void
-_print_frag6(u_char *p, _U_ int length)
+print_frag6(u_char *p, _U_ int length)
 {
     struct ip6_hdr *ip6;
     struct ip6_ext_hdr *ext;
@@ -291,13 +295,14 @@ _print_frag6(u_char *p, _U_ int length)
 
     printf("%s > %s:", ip6_ntoa(&ip6->ip6_src), ip6_ntoa(&ip6->ip6_dst));
     printf(" fragment: next %hhu offset %d%s ident 0x%08x",
-        ext->ext_nxt, off,
-        (ext->ext_data.fragment.offlg & IP6_MORE_FRAG) ? " MF" : "",
-        htonl(ext->ext_data.fragment.ident));
+           ext->ext_nxt,
+           off,
+           (ext->ext_data.fragment.offlg & IP6_MORE_FRAG) ? " MF" : "",
+           htonl(ext->ext_data.fragment.ident));
 }
 
 static void
-_print_ip(u_char *p, int length)
+print_ip(u_char *p, int length)
 {
     struct ip_hdr *ip;
     int ip_off, ip_hl, ip_len;
@@ -321,28 +326,29 @@ _print_ip(u_char *p, int length)
     if ((ip_off & IP_OFFMASK) == 0) {
         switch (ip->ip_p) {
         case IP_PROTO_TCP:
-            _print_tcp(AF_INET, p, ip_len);
+            print_tcp(AF_INET, p, ip_len);
             break;
         case IP_PROTO_UDP:
-            _print_udp(AF_INET, p, ip_len);
+            print_udp(AF_INET, p, ip_len);
             break;
         case IP_PROTO_ICMP:
-            _print_icmp(p, ip_len);
+            print_icmp(p, ip_len);
             break;
         default:
-            printf("%s > %s:", ip_ntoa(&ip->ip_src),
-                ip_ntoa(&ip->ip_dst));
+            printf("%s > %s:", ip_ntoa(&ip->ip_src), ip_ntoa(&ip->ip_dst));
             printf(" ip-proto-%d %d", ip->ip_p, ip_len);
             break;
         }
     }
     /* Handle more frags. */
-    if (ip_off & (IP_MF|IP_OFFMASK)) {
+    if (ip_off & (IP_MF | IP_OFFMASK)) {
         if (ip_off & IP_OFFMASK)
-            printf("%s > %s:", ip_ntoa(&ip->ip_src),
-                ip_ntoa(&ip->ip_dst));
-        printf(" (frag %d:%d@%d%s)", ntohs(ip->ip_id), ip_len - ip_hl,
-            (ip_off & IP_OFFMASK) << 3, (ip_off & IP_MF) ? "+" : "");
+            printf("%s > %s:", ip_ntoa(&ip->ip_src), ip_ntoa(&ip->ip_dst));
+        printf(" (frag %d:%d@%d%s)",
+               ntohs(ip->ip_id),
+               ip_len - ip_hl,
+               (ip_off & IP_OFFMASK) << 3,
+               (ip_off & IP_MF) ? "+" : "");
     } else if (ip_off & IP_DF)
         printf(" (DF)");
 
@@ -353,7 +359,7 @@ _print_ip(u_char *p, int length)
 }
 
 static void
-_print_ip6(u_char *p, int length)
+print_ip6(u_char *p, int length)
 {
     struct ip6_hdr *ip6;
     int plen;
@@ -368,24 +374,22 @@ _print_ip6(u_char *p, int length)
     plen = htons(ip6->ip6_plen);
 
     switch (ip6->ip6_nxt) {
-        case IP_PROTO_TCP:
-            _print_tcp(AF_INET6, p, plen);
-            break;
-        case IP_PROTO_UDP:
-            _print_udp(AF_INET6, p, plen);
-            break;
-        case IP_PROTO_ICMPV6:
-            _print_icmp6(p, plen);
-            break;
-        case IP_PROTO_FRAGMENT:
-            _print_frag6(p, plen);
-            break;
-        default:
-            printf("%s > %s:", ip6_ntoa(&ip6->ip6_src),
-                ip6_ntoa(&ip6->ip6_dst));
-            printf(" ip-proto-%hhu ttl %hhu  payload len %d", ip6->ip6_nxt,
-                ip6->ip6_hlim, plen);
-            break;
+    case IP_PROTO_TCP:
+        print_tcp(AF_INET6, p, plen);
+        break;
+    case IP_PROTO_UDP:
+        print_udp(AF_INET6, p, plen);
+        break;
+    case IP_PROTO_ICMPV6:
+        print_icmp6(p, plen);
+        break;
+    case IP_PROTO_FRAGMENT:
+        print_frag6(p, plen);
+        break;
+    default:
+        printf("%s > %s:", ip6_ntoa(&ip6->ip6_src), ip6_ntoa(&ip6->ip6_dst));
+        printf(" ip-proto-%hhu ttl %hhu  payload len %d", ip6->ip6_nxt, ip6->ip6_hlim, plen);
+        break;
     }
 
     if (ip6->ip6_hlim <= 1)
@@ -393,13 +397,13 @@ _print_ip6(u_char *p, int length)
 }
 
 static void
-_print_eth(struct eth_hdr* e, int length)
+print_eth(struct eth_hdr *e, int length)
 {
-        char d[20], s[20];
-        eth_ntop(&e->eth_dst, &d[0], sizeof(d));
-        eth_ntop(&e->eth_src, &s[0], sizeof(s));
+    char d[20], s[20];
+    eth_ntop(&e->eth_dst, &d[0], sizeof(d));
+    eth_ntop(&e->eth_src, &s[0], sizeof(s));
 
-        printf("%s > %s type 0x%04hx length %d", d, s, htons(e->eth_type), length);
+    printf("%s > %s type 0x%04hx length %d", d, s, htons(e->eth_type), length);
 }
 
 static char *
@@ -410,8 +414,7 @@ timerntoa(struct timeval *tv)
 
     usec = (tv->tv_sec * 1000000) + tv->tv_usec;
 
-    snprintf(buf, sizeof(buf), "%d.%03d ms",
-        (int)(usec / 1000), (int)(usec % 1000));
+    snprintf(buf, sizeof(buf), "%d.%03d ms", (int)(usec / 1000), (int)(usec % 1000));
 
     return (buf);
 }
@@ -421,15 +424,16 @@ print_apply(_U_ void *d, struct pktq *pktq)
 {
     struct pkt *pkt;
 
-    TAILQ_FOREACH(pkt, pktq, pkt_next) {
+    TAILQ_FOREACH(pkt, pktq, pkt_next)
+    {
         uint16_t eth_type = htons(pkt->pkt_eth->eth_type);
 
         if (eth_type == ETH_TYPE_IP)
-        _print_ip(pkt->pkt_eth_data, pkt->pkt_end - pkt->pkt_eth_data);
+            print_ip(pkt->pkt_eth_data, pkt->pkt_end - pkt->pkt_eth_data);
         else if (eth_type == ETH_TYPE_IPV6)
-          _print_ip6(pkt->pkt_eth_data, pkt->pkt_end - pkt->pkt_eth_data);
+            print_ip6(pkt->pkt_eth_data, pkt->pkt_end - pkt->pkt_eth_data);
         else
-            _print_eth(pkt->pkt_eth, pkt->pkt_end - pkt->pkt_data);
+            print_eth(pkt->pkt_eth, pkt->pkt_end - pkt->pkt_data);
         if (timerisset(&pkt->pkt_ts))
             printf(" [delay %s]", timerntoa(&pkt->pkt_ts));
         printf("\n");
@@ -438,9 +442,9 @@ print_apply(_U_ void *d, struct pktq *pktq)
 }
 
 struct mod mod_print = {
-    "print",        /* name */
-    "print",        /* usage */
-    NULL,            /* init */
-    print_apply,        /* apply */
-    NULL            /* close */
+        "print",     /* name */
+        "print",     /* usage */
+        NULL,        /* init */
+        print_apply, /* apply */
+        NULL         /* close */
 };
