@@ -16,23 +16,18 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-#include "defines.h"
-#include "common.h"
 #include "sleep.h"
-
-#include <sys/types.h>
-#include <sys/time.h>
-#include <unistd.h>
-#include <errno.h>
+#include "config.h"
+#include "common.h"
 #include <string.h>
+#include <sys/time.h>
 
 #ifdef HAVE_SYS_EVENT
 #include <sys/event.h>
 #endif
 
 /* necessary for ioport_sleep() functions */
-#ifdef HAVE_SYS_IO_H /* Linux */
+#if defined HAVE_IOPORT_SLEEP__ && defined HAVE_SYS_IO_H /* Linux */
 #include <sys/io.h>
 #elif defined HAVE_ARCHITECTURE_I386_PIO_H /* OS X */
 #include <architecture/i386/pio.h>
@@ -42,20 +37,19 @@
 static int ioport_sleep_value;
 #endif
 
-void 
-ioport_sleep_init(void) 
+void
+ioport_sleep_init(void)
 {
 #if defined HAVE_IOPORT_SLEEP__
     ioperm(0x80, 1, 1);
-    ioport_sleep_value = inb(0x80);    
+    ioport_sleep_value = inb(0x80);
 #else
     err(-1, "Platform does not support IO Port for timing");
 #endif
 }
 
-void 
-ioport_sleep(sendpacket_t *sp _U_, const struct timespec *nap _U_,
-        struct timeval *now _U_,  bool flush _U_)
+void
+ioport_sleep(sendpacket_t *sp _U_, const struct timespec *nap _U_, struct timeval *now _U_, bool flush _U_)
 {
 #if defined HAVE_IOPORT_SLEEP__
     struct timeval nap_for;
@@ -64,33 +58,26 @@ ioport_sleep(sendpacket_t *sp _U_, const struct timespec *nap _U_,
 
     TIMESPEC_TO_TIMEVAL(&nap_for, nap);
 
-    /* 
-     * process the seconds, we do this in a loop so we don't have to 
+    /*
+     * process the seconds, we do this in a loop so we don't have to
      * use slower 64bit integers or worry about integer overflows.
      */
-    for (i = 0; i < nap_for.tv_sec; i ++) {
+    for (i = 0; i < nap_for.tv_sec; i++) {
         usec = SEC_TO_MICROSEC(nap_for.tv_sec);
         while (usec > 0) {
-            usec --;
+            usec--;
             outb(ioport_sleep_value, 0x80);
         }
     }
 
     /* process the usec */
     usec = nap->tv_nsec / 1000;
-    usec --; /* fudge factor for all the above */
+    usec--; /* fudge factor for all the above */
     while (usec > 0) {
-        usec --;
-    	outb(ioport_sleep_value, 0x80);
+        usec--;
+        outb(ioport_sleep_value, 0x80);
     }
 #else
     err(-1, "Platform does not support IO Port for timing");
 #endif
-
-#ifdef HAVE_NETMAP
-    if (flush)
-        ioctl(sp->handle.fd, NIOCTXSYNC, NULL);   /* flush TX buffer */
-#endif /* HAVE_NETMAP */
-
-    gettimeofday(now, NULL);
 }
