@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2012 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,25 +18,19 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
 #include "defines.h"
+#include "config.h"
 #include "common.h"
-
+#include "tcpcapinfo_opts.h"
+#include <errno.h>
 #include <fcntl.h>
-#include <sys/types.h>
-#include <sys/uio.h>
-#include <unistd.h>
+#include <inttypes.h>
 #include <pcap.h>
-#include <sys/stat.h>
 #include <stdio.h>
 #include <string.h>
-#include <errno.h>
-#include <inttypes.h>
-
-#define __STDC_FORMAT_MACROS 1
-#include <inttypes.h>
-
-#include "tcpcapinfo_opts.h"
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <unistd.h>
 
 static int do_checksum_math(u_int16_t *data, int len);
 
@@ -52,26 +46,24 @@ char is_not_swapped[] = "little-endian";
 char is_swapped[] = "big-endian";
 #endif
 
-int read_packet(int fd, uint32_t len, char *fname);
-
 /*
  * Standard libpcap format.
  */
-#define TCPDUMP_MAGIC           0xa1b2c3d4
+#define TCPDUMP_MAGIC 0xa1b2c3d4
 
 /*
  * Alexey Kuznetzov's modified libpcap format.
  */
 #define KUZNETZOV_TCPDUMP_MAGIC 0xa1b2cd34
 struct pcap_timeval {
-    bpf_int32 tv_sec;           /* seconds */
-    bpf_int32 tv_usec;          /* microseconds */
+    bpf_int32 tv_sec;  /* seconds */
+    bpf_int32 tv_usec; /* microseconds */
 };
 struct pcap_sf_patched_pkthdr {
-    struct pcap_timeval ts;     /* time stamp */
-    bpf_u_int32 caplen;         /* length of portion present */
-    bpf_u_int32 len;            /* length this packet (off wire) */
-    int         index;
+    struct pcap_timeval ts; /* time stamp */
+    bpf_u_int32 caplen;     /* length of portion present */
+    bpf_u_int32 len;        /* length this packet (off wire) */
+    int index;
     unsigned short protocol;
     unsigned char pkt_type;
 };
@@ -86,19 +78,18 @@ struct pcap_sf_patched_pkthdr {
  * Navtel Communcations' format, with nanosecond timestamps,
  * as per a request from Dumas Hwang <dumas.hwang@navtelcom.com>.
  */
-#define NAVTEL_TCPDUMP_MAGIC    0xa12b3c4d
+#define NAVTEL_TCPDUMP_MAGIC 0xa12b3c4d
 
 /*
  * Normal libpcap format, except for seconds/nanoseconds timestamps,
  * as per a request by Ulf Lamping <ulf.lamping@web.de>
  */
-#define NSEC_TCPDUMP_MAGIC      0xa1b23c4d
-
+#define NSEC_TCPDUMP_MAGIC 0xa1b23c4d
 
 int
 main(int argc, char *argv[])
 {
-    int i, fd, swapped, pkthdrlen, ret, optct, backwards, caplentoobig;
+    int i, fd, swapped, pkthdrlen, optct, backwards, caplentoobig;
     struct pcap_file_header pcap_fh;
     struct pcap_pkthdr pcap_ph;
     struct pcap_sf_patched_pkthdr pcap_patched_ph; /* Kuznetzov */
@@ -107,6 +98,7 @@ main(int argc, char *argv[])
     uint64_t pktcnt;
     uint32_t readword;
     int32_t last_sec, last_usec, caplen, maxread;
+    ssize_t ret;
 
     optct = optionProcess(&tcpcapinfoOptions, argc, argv);
     argc -= optct;
@@ -125,12 +117,12 @@ main(int argc, char *argv[])
         if (fstat(fd, &statinfo) < 0)
             errx(-1, "Error getting file stat info %s: %s", argv[i], strerror(errno));
 
-        printf("file size   = %"PRIu64" bytes\n", (uint64_t)statinfo.st_size);
+        printf("file size   = %" PRIu64 " bytes\n", (uint64_t)statinfo.st_size);
 
-        if ((ret = read(fd, &buf, sizeof(pcap_fh))) != sizeof(pcap_fh))
+        if ((ret = read(fd, &buf, sizeof(pcap_fh))) != (int)sizeof(pcap_fh))
             errx(-1, "File too small.  Unable to read pcap_file_header from %s", argv[i]);
 
-        dbgx(3, "Read %d bytes for file header", ret);
+        dbgx(3, "Read %ld bytes for file header", ret);
 
         swapped = 0;
 
@@ -139,55 +131,55 @@ main(int argc, char *argv[])
         pkthdrlen = 16; /* pcap_pkthdr isn't the actual on-disk format for 64bit systems! */
 
         switch (pcap_fh.magic) {
-            case TCPDUMP_MAGIC:
-            printf("magic       = 0x%08"PRIx32" (tcpdump) (%s)\n", pcap_fh.magic, is_not_swapped);
+        case TCPDUMP_MAGIC:
+            printf("magic       = 0x%08" PRIx32 " (tcpdump) (%s)\n", pcap_fh.magic, is_not_swapped);
             break;
 
-            case SWAPLONG(TCPDUMP_MAGIC):
-            printf("magic       = 0x%08"PRIx32" (tcpdump/swapped) (%s)\n", pcap_fh.magic, is_swapped);
+        case SWAPLONG(TCPDUMP_MAGIC):
+            printf("magic       = 0x%08" PRIx32 " (tcpdump/swapped) (%s)\n", pcap_fh.magic, is_swapped);
             swapped = 1;
             break;
 
-            case KUZNETZOV_TCPDUMP_MAGIC:
+        case KUZNETZOV_TCPDUMP_MAGIC:
             pkthdrlen = sizeof(pcap_patched_ph);
-            printf("magic       = 0x%08"PRIx32" (Kuznetzov) (%s)\n", pcap_fh.magic, is_not_swapped);
+            printf("magic       = 0x%08" PRIx32 " (Kuznetzov) (%s)\n", pcap_fh.magic, is_not_swapped);
             break;
 
-            case SWAPLONG(KUZNETZOV_TCPDUMP_MAGIC):
+        case SWAPLONG(KUZNETZOV_TCPDUMP_MAGIC):
             pkthdrlen = sizeof(pcap_patched_ph);
-            printf("magic       = 0x%08"PRIx32" (Kuznetzov/swapped) (%s)\n", pcap_fh.magic, is_swapped);
+            printf("magic       = 0x%08" PRIx32 " (Kuznetzov/swapped) (%s)\n", pcap_fh.magic, is_swapped);
             swapped = 1;
             break;
 
-            case FMESQUITA_TCPDUMP_MAGIC:
-            printf("magic       = 0x%08"PRIx32" (Fmesquita) (%s)\n", pcap_fh.magic, is_not_swapped);
+        case FMESQUITA_TCPDUMP_MAGIC:
+            printf("magic       = 0x%08" PRIx32 " (Fmesquita) (%s)\n", pcap_fh.magic, is_not_swapped);
             break;
 
-            case SWAPLONG(FMESQUITA_TCPDUMP_MAGIC):
-            printf("magic       = 0x%08"PRIx32" (Fmesquita) (%s)\n", pcap_fh.magic, is_swapped);
+        case SWAPLONG(FMESQUITA_TCPDUMP_MAGIC):
+            printf("magic       = 0x%08" PRIx32 " (Fmesquita) (%s)\n", pcap_fh.magic, is_swapped);
             swapped = 1;
             break;
 
-            case NAVTEL_TCPDUMP_MAGIC:
-            printf("magic       = 0x%08"PRIx32" (Navtel) (%s)\n", pcap_fh.magic, is_not_swapped);
+        case NAVTEL_TCPDUMP_MAGIC:
+            printf("magic       = 0x%08" PRIx32 " (Navtel) (%s)\n", pcap_fh.magic, is_not_swapped);
             break;
 
-            case SWAPLONG(NAVTEL_TCPDUMP_MAGIC):
-            printf("magic       = 0x%08"PRIx32" (Navtel/swapped) (%s)\n", pcap_fh.magic, is_swapped);
+        case SWAPLONG(NAVTEL_TCPDUMP_MAGIC):
+            printf("magic       = 0x%08" PRIx32 " (Navtel/swapped) (%s)\n", pcap_fh.magic, is_swapped);
             swapped = 1;
             break;
 
-            case NSEC_TCPDUMP_MAGIC:
-            printf("magic       = 0x%08"PRIx32" (Nsec) (%s)\n", pcap_fh.magic, is_not_swapped);
+        case NSEC_TCPDUMP_MAGIC:
+            printf("magic       = 0x%08" PRIx32 " (Nsec) (%s)\n", pcap_fh.magic, is_not_swapped);
             break;
 
-            case SWAPLONG(NSEC_TCPDUMP_MAGIC):
-            printf("magic       = 0x%08"PRIx32" (Nsec/swapped) (%s)\n", pcap_fh.magic, is_swapped);
+        case SWAPLONG(NSEC_TCPDUMP_MAGIC):
+            printf("magic       = 0x%08" PRIx32 " (Nsec/swapped) (%s)\n", pcap_fh.magic, is_swapped);
             swapped = 1;
             break;
 
-            default:
-            printf("magic       = 0x%08"PRIx32" (unknown)\n", pcap_fh.magic);
+        default:
+            printf("magic       = 0x%08" PRIx32 " (unknown)\n", pcap_fh.magic);
         }
 
         if (swapped == 1) {
@@ -200,10 +192,10 @@ main(int argc, char *argv[])
         }
 
         printf("version     = %hu.%hu\n", pcap_fh.version_major, pcap_fh.version_minor);
-        printf("thiszone    = 0x%08"PRIx32"\n", pcap_fh.thiszone);
-        printf("sigfigs     = 0x%08"PRIx32"\n", pcap_fh.sigfigs);
-        printf("snaplen     = %"PRIu32"\n", pcap_fh.snaplen);
-        printf("linktype    = 0x%08"PRIx32"\n", pcap_fh.linktype);
+        printf("thiszone    = 0x%08" PRIx32 "\n", pcap_fh.thiszone);
+        printf("sigfigs     = 0x%08" PRIx32 "\n", pcap_fh.sigfigs);
+        printf("snaplen     = %" PRIu32 "\n", pcap_fh.snaplen);
+        printf("linktype    = 0x%08" PRIx32 "\n", pcap_fh.linktype);
 
         if (pcap_fh.version_major != 2 && pcap_fh.version_minor != 4) {
             printf("Sorry, we only support file format version 2.4\n");
@@ -222,11 +214,11 @@ main(int argc, char *argv[])
         pktcnt = 0;
         last_sec = 0;
         last_usec = 0;
-        while ((ret = read(fd, &buf, pkthdrlen)) == pkthdrlen) {
-            pktcnt ++;
+        while ((ret = read(fd, &buf, (size_t)pkthdrlen)) == pkthdrlen) {
+            pktcnt++;
             backwards = 0;
             caplentoobig = 0;
-            dbgx(3, "Read %d bytes for packet %"PRIu64" header", ret, pktcnt);
+            dbgx(3, "Read %ld bytes for packet %" PRIu64 " header", ret, pktcnt);
 
             memset(&pcap_ph, 0, sizeof(pcap_ph));
 
@@ -243,17 +235,22 @@ main(int argc, char *argv[])
                     pcap_patched_ph.index = SWAPLONG(pcap_patched_ph.index);
                     pcap_patched_ph.protocol = SWAPSHORT(pcap_patched_ph.protocol);
                 }
-                printf("%"PRIu64"\t%4"PRIu32"\t\t%4"PRIu32"\t\t%"
-                        PRIx32".%"PRIx32"\t\t%4"PRIu32"\t%4hu\t%4hhu", 
-                        pktcnt, pcap_patched_ph.len, pcap_patched_ph.caplen, 
-                        pcap_patched_ph.ts.tv_sec, pcap_patched_ph.ts.tv_usec,
-                        pcap_patched_ph.index, pcap_patched_ph.protocol, pcap_patched_ph.pkt_type);
+                printf("%" PRIu64 "\t%4" PRIu32 "\t\t%4" PRIu32 "\t\t%" PRIx32 ".%" PRIx32 "\t\t%4" PRIu32
+                       "\t%4hu\t%4hhu",
+                       pktcnt,
+                       pcap_patched_ph.len,
+                       pcap_patched_ph.caplen,
+                       pcap_patched_ph.ts.tv_sec,
+                       pcap_patched_ph.ts.tv_usec,
+                       pcap_patched_ph.index,
+                       pcap_patched_ph.protocol,
+                       pcap_patched_ph.pkt_type);
 
                 if (pcap_fh.snaplen < pcap_patched_ph.caplen) {
                     caplentoobig = 1;
                 }
 
-                caplen = pcap_patched_ph.caplen;
+                caplen = (int32_t)pcap_patched_ph.caplen;
 
             } else {
                 /* manually map on-disk bytes to our memory structure */
@@ -271,30 +268,22 @@ main(int argc, char *argv[])
                     pcap_ph.ts.tv_sec = SWAPLONG(pcap_ph.ts.tv_sec);
                     pcap_ph.ts.tv_usec = SWAPLONG(pcap_ph.ts.tv_usec);
                 }
-                printf("%"PRIu64"\t%4"PRIu32"\t\t%4"PRIu32"\t\t%"
-                        PRIx32".%"PRIx32,
-                        pktcnt, pcap_ph.len, pcap_ph.caplen, 
-                        (unsigned int)pcap_ph.ts.tv_sec, (unsigned int)pcap_ph.ts.tv_usec);
+                printf("%" PRIu64 "\t%4" PRIu32 "\t\t%4" PRIu32 "\t\t%" PRIx32 ".%" PRIx32,
+                       pktcnt,
+                       pcap_ph.len,
+                       pcap_ph.caplen,
+                       (unsigned int)pcap_ph.ts.tv_sec,
+                       (unsigned int)pcap_ph.ts.tv_usec);
                 if (pcap_fh.snaplen < pcap_ph.caplen || pcap_ph.caplen > MAX_SNAPLEN) {
                     caplentoobig = 1;
                 }
-                caplen = pcap_ph.caplen;
-            }
-
-            if (caplentoobig) {
-                printf("\n\nCapture file appears to be damaged or corrupt.\n"
-                        "Contains packet of size %d, bigger than snap length %u\n",
-                        caplen, pcap_fh.snaplen);
-
-                close(fd);
-                break;
+                caplen = (int32_t)pcap_ph.caplen;
             }
 
             /* check to make sure timestamps don't go backwards */
             if (last_sec > 0 && last_usec > 0) {
-                if ((pcap_ph.ts.tv_sec == last_sec) ? 
-                        (pcap_ph.ts.tv_usec < last_usec) : 
-                        (pcap_ph.ts.tv_sec < last_sec)) {
+                if ((pcap_ph.ts.tv_sec == last_sec) ? (pcap_ph.ts.tv_usec < last_usec)
+                                                    : (pcap_ph.ts.tv_sec < last_sec)) {
                     backwards = 1;
                 }
             }
@@ -302,8 +291,8 @@ main(int argc, char *argv[])
                 last_sec = pcap_patched_ph.ts.tv_sec;
                 last_usec = pcap_patched_ph.ts.tv_usec;
             } else {
-                last_sec = pcap_ph.ts.tv_sec;
-                last_usec = pcap_ph.ts.tv_usec;
+                last_sec = (int32_t)pcap_ph.ts.tv_sec;
+                last_usec = (int32_t)pcap_ph.ts.tv_usec;
             }
 
             /* read the frame */
@@ -323,15 +312,24 @@ main(int argc, char *argv[])
             printf("\t%x\t", do_checksum_math((u_int16_t *)buf, maxread));
 
             /* print the Note */
-            if (! backwards && ! caplentoobig) {
+            if (!backwards && !caplentoobig)
                 printf("OK\n");
-            } else if (backwards && ! caplentoobig) {
+            else if (backwards && !caplentoobig)
                 printf("BAD_TS\n");
-            } else if (caplentoobig && ! backwards) {
+            else if (caplentoobig && !backwards)
                 printf("TOOBIG\n");
-            } else if (backwards && caplentoobig) {
+            else if (backwards && caplentoobig)
                 printf("BAD_TS|TOOBIG");
-            } 
+
+            if (caplentoobig) {
+                printf("\n\nCapture file appears to be damaged or corrupt.\n"
+                       "Contains packet of size %d, bigger than snap length %u\n",
+                       caplen,
+                       pcap_fh.snaplen);
+
+                close(fd);
+                break;
+            }
         }
     }
 
@@ -364,4 +362,3 @@ do_checksum_math(u_int16_t *data, int len)
 
     return (sum);
 }
-
