@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,18 +18,14 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _PLUGINS_H_
-#define _PLUGINS_H_
+#pragma once
 
-#include "plugins_types.h"
 #include "plugins_api.h"
 
-/* 
- * Encoder DLT plugin authors who create API functions should add their 
+/*
+ * Encoder DLT plugin authors who create API functions should add their
  * API header files here
  */
 #include "plugins/dlt_en10mb/en10mb_api.h"
 #include "plugins/dlt_hdlc/hdlc_api.h"
 #include "plugins/dlt_user/user_api.h"
-
-#endif
