@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,16 +18,13 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "hdlc.h"
+#include "dlt_utils.h"
+#include "tcpedit.h"
+#include "tcpedit_stub.h"
 #include <stdlib.h>
 #include <string.h>
 
-#include "tcpedit.h"
-#include "common.h"
-#include "tcpr.h"
-#include "dlt_utils.h"
-#include "tcpedit_stub.h"
-#include "hdlc.h"
-
 static char dlt_name[] = "hdlc";
 static char _U_ dlt_prefix[] = "hdlc";
 static uint16_t dlt_value = DLT_C_HDLC;
@@ -43,7 +40,7 @@ static uint16_t dlt_value = DLT_C_HDLC;
  * - Add the plugin to the context's plugin chain
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_hdlc_register(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -54,16 +51,18 @@ dlt_hdlc_register(tcpeditdlt_t *ctx)
 
     /* FIXME: set what we provide & require  */
     plugin->provides += PLUGIN_MASK_PROTO;
-    plugin->requires += PLUGIN_MASK_PROTO;
+    plugin->
+        requires
+    += PLUGIN_MASK_PROTO;
 
-     /* what is our DLT value? */
+    /* what is our DLT value? */
     plugin->dlt = dlt_value;
 
     /* set the prefix name of our plugin.  This is also used as the prefix for our options */
     plugin->name = safe_strdup(dlt_prefix);
 
-    /* 
-     * Point to our functions, note, you need a function for EVERY method.  
+    /*
+     * Point to our functions, note, you need a function for EVERY method.
      * Even if it is only an empty stub returning success.
      */
     plugin->plugin_init = dlt_hdlc_init;
@@ -77,36 +76,34 @@ dlt_hdlc_register(tcpeditdlt_t *ctx)
     plugin->plugin_get_layer3 = dlt_hdlc_get_layer3;
     plugin->plugin_merge_layer3 = dlt_hdlc_merge_layer3;
     plugin->plugin_get_mac = dlt_hdlc_get_mac;
-    
+
     /* add it to the available plugin list */
     return tcpedit_dlt_addplugin(ctx, plugin);
 }
 
- 
 /*
  * Initializer function.  This function is called only once, if and only if
- * this plugin will be utilized.  Remember, if you need to keep track of any state, 
+ * this plugin will be utilized.  Remember, if you need to keep track of any state,
  * store it in your plugin->config, not a global!
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_hdlc_init(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
     hdlc_config_t *config;
     assert(ctx);
-    
+
     if ((plugin = tcpedit_dlt_getplugin(ctx, dlt_value)) == NULL) {
         tcpedit_seterr(ctx->tcpedit, "Unable to initialize unregistered plugin %s", dlt_name);
         return TCPEDIT_ERROR;
     }
-    
+
     /* allocate memory for our deocde extra data */
     if (ctx->decoded_extra_size > 0) {
         if (ctx->decoded_extra_size < sizeof(hdlc_extra_t)) {
             ctx->decoded_extra_size = sizeof(hdlc_extra_t);
-            ctx->decoded_extra = safe_realloc(ctx->decoded_extra,
-                                              ctx->decoded_extra_size);
+            ctx->decoded_extra = safe_realloc(ctx->decoded_extra, ctx->decoded_extra_size);
         }
     } else {
         ctx->decoded_extra_size = sizeof(hdlc_extra_t);
@@ -129,7 +126,7 @@ dlt_hdlc_init(tcpeditdlt_t *ctx)
  * Unless you allocated some memory in dlt_hdlc_init(), this is just an stub.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_hdlc_cleanup(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -155,14 +152,13 @@ dlt_hdlc_cleanup(tcpeditdlt_t *ctx)
  * bit mask.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_hdlc_parse_opts(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
     hdlc_config_t *config;
     assert(ctx);
 
-
     plugin = tcpedit_dlt_getplugin(ctx, dlt_value);
     if (!plugin)
         return TCPEDIT_ERROR;
@@ -174,11 +170,11 @@ dlt_hdlc_parse_opts(tcpeditdlt_t *ctx)
     if (HAVE_OPT(HDLC_CONTROL)) {
         config->control = (uint16_t)OPT_VALUE_HDLC_CONTROL;
     }
-    
+
     if (HAVE_OPT(HDLC_ADDRESS)) {
         config->address = (uint16_t)OPT_VALUE_HDLC_ADDRESS;
     }
-    
+
     return TCPEDIT_OK; /* success */
 }
 
@@ -192,8 +188,8 @@ dlt_hdlc_parse_opts(tcpeditdlt_t *ctx)
  * - ctx->decoded_extra
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
-dlt_hdlc_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_hdlc_decode(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     cisco_hdlc_t *hdlc;
     hdlc_extra_t *extra;
@@ -202,20 +198,20 @@ dlt_hdlc_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 
     if ((size_t)pktlen < sizeof(*hdlc))
         return TCPEDIT_ERROR;
-    
+
     if (ctx->decoded_extra_size < sizeof(*extra))
         return TCPEDIT_ERROR;
 
     extra = (hdlc_extra_t *)ctx->decoded_extra;
 
     hdlc = (cisco_hdlc_t *)packet;
-    
+
     ctx->proto = hdlc->protocol;
     ctx->l2len = 4;
-    
+
     extra->address = hdlc->address;
     extra->control = hdlc->control;
-    
+
     return TCPEDIT_OK; /* success */
 }
 
@@ -223,7 +219,7 @@ dlt_hdlc_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function to encode the layer 2 header back into the packet.
  * Returns: total packet len or TCPEDIT_ERROR
  */
-int 
+int
 dlt_hdlc_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, _U_ tcpr_dir_t dir)
 {
     cisco_hdlc_t *hdlc;
@@ -250,11 +246,11 @@ dlt_hdlc_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, _U_ tcpr_dir_t di
         memcpy(packet + 4, (tmpbuff + ctx->l2len), pktlen - ctx->l2len);
         safe_free(tmpbuff);
     }
-    
+
     /* update the total packet length */
     newpktlen = pktlen + 4 - ctx->l2len;
-    
-    /* 
+
+    /*
      * HDLC doesn't support direction, since we have no real src/dst addresses
      * to deal with, so we just use the original packet data or option data
      */
@@ -280,7 +276,7 @@ dlt_hdlc_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, _U_ tcpr_dir_t di
         tcpedit_seterr(ctx->tcpedit, "%s", "Non-HDLC packet requires --hdlc-address");
         return TCPEDIT_ERROR;
     }
-    
+
     /* set the control field */
     if (config->control < 65535) {
         hdlc->control = (uint8_t)config->control;
@@ -288,20 +284,20 @@ dlt_hdlc_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, _U_ tcpr_dir_t di
         hdlc->control = extra->hdlc;
     } else {
         tcpedit_seterr(ctx->tcpedit, "%s", "Non-HDLC packet requires --hdlc-control");
-        return TCPEDIT_ERROR;      
+        return TCPEDIT_ERROR;
     }
-    
+
     /* copy over our protocol */
     hdlc->protocol = ctx->proto;
-    
+
     return newpktlen; /* success */
 }
 
 /*
  * Function returns the Layer 3 protocol type of the given packet, or TCPEDIT_ERROR on error
  */
-int 
-dlt_hdlc_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_hdlc_proto(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     cisco_hdlc_t *hdlc;
     assert(ctx);
@@ -309,9 +305,9 @@ dlt_hdlc_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 
     if (pktlen < 4)
         return TCPEDIT_ERROR;
-    
+
     hdlc = (cisco_hdlc_t *)packet;
-    
+
     return hdlc->protocol;
 }
 
@@ -319,7 +315,7 @@ dlt_hdlc_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function returns a pointer to the layer 3 protocol header or NULL on error
  */
 u_char *
-dlt_hdlc_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
+dlt_hdlc_get_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen)
 {
     int l2len;
     assert(ctx);
@@ -339,29 +335,25 @@ dlt_hdlc_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
  * like SPARC
  */
 u_char *
-dlt_hdlc_merge_layer3(tcpeditdlt_t *ctx,
-                      u_char *packet,
-                      const int pktlen,
-                      u_char *ipv4_data,
-                      u_char *ipv6_data)
+dlt_hdlc_merge_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen, u_char *ipv4_data, u_char *ipv6_data)
 {
     int l2len;
     assert(ctx);
     assert(packet);
     assert(ipv4_data || ipv6_data);
-    
+
     l2len = dlt_hdlc_l2len(ctx, packet, pktlen);
     if (l2len == -1 || pktlen < l2len)
         return NULL;
-    
+
     return tcpedit_dlt_l3data_merge(ctx, packet, pktlen, ipv4_data ?: ipv6_data, l2len);
 }
 
-/* 
+/*
  * return the length of the L2 header of the current packet
  */
 int
-dlt_hdlc_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+dlt_hdlc_l2len(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     assert(ctx);
     assert(packet);
@@ -376,9 +368,9 @@ dlt_hdlc_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 /*
  * return a static pointer to the source/destination MAC address
  * return NULL on error/address doesn't exist
- */    
+ */
 u_char *
-dlt_hdlc_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, const int pktlen)
+dlt_hdlc_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, int pktlen)
 {
     assert(ctx);
     assert(packet);
@@ -387,25 +379,19 @@ dlt_hdlc_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *pac
         return NULL;
 
     /* FIXME: return a ptr to the source or dest mac address. */
-    switch(mac) {
+    switch (mac) {
     case SRC_MAC:
-        return(NULL);
-        break;
-        
+        return (NULL);
     case DST_MAC:
         memcpy(ctx->dstmac, packet, 2);
-        return(ctx->dstmac);
-        break;
-        
+        return (ctx->dstmac);
     default:
         errx(-1, "Invalid tcpeditdlt_mac_type_t: %d", mac);
     }
-    return(NULL);
 }
 
-tcpeditdlt_l2addr_type_t 
+tcpeditdlt_l2addr_type_t
 dlt_hdlc_l2addr_type(void)
 {
     return C_HDLC;
 }
-
