@@ -18,8 +18,7 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _DLT_linuxsll_H_
-#define _DLT_linuxsll_H_
+#pragma once
 
 #include "plugins_types.h"
 #include "linuxsll_types.h"
@@ -33,22 +32,19 @@ int dlt_linuxsll_register(tcpeditdlt_t *ctx);
 int dlt_linuxsll_init(tcpeditdlt_t *ctx);
 int dlt_linuxsll_cleanup(tcpeditdlt_t *ctx);
 int dlt_linuxsll_parse_opts(tcpeditdlt_t *ctx);
-int dlt_linuxsll_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen);
+int dlt_linuxsll_decode(tcpeditdlt_t *ctx, const u_char *packet, int pktlen);
 int dlt_linuxsll_encode(tcpeditdlt_t *ctx, u_char *packet, int pktlen, tcpr_dir_t dir);
-int dlt_linuxsll_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen);
-u_char *dlt_linuxsll_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen);
+int dlt_linuxsll_proto(tcpeditdlt_t *ctx, const u_char *packet, int pktlen);
+u_char *dlt_linuxsll_get_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen);
 u_char *dlt_linuxsll_merge_layer3(tcpeditdlt_t *ctx,
                                   u_char *packet,
-                                  const int pktlen,
+                                  int pktlen,
                                   u_char *ipv4_data,
                                   u_char *ipv6_data);
 tcpeditdlt_l2addr_type_t dlt_linuxsll_l2addr_type(void);
-int dlt_linuxsll_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen);
-u_char *dlt_linuxsll_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, const int pktlen);
+int dlt_linuxsll_l2len(tcpeditdlt_t *ctx, const u_char *packet, int pktlen);
+u_char *dlt_linuxsll_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, int pktlen);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif
-
