@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,8 +18,7 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _DLT_loop_H_
-#define _DLT_loop_H_
+#pragma once
 
 #include "plugins_types.h"
 
@@ -27,7 +26,6 @@
 extern "C" {
 #endif
 
-
 int dlt_loop_register(tcpeditdlt_t *ctx);
 int dlt_loop_init(tcpeditdlt_t *ctx);
 int dlt_loop_cleanup(tcpeditdlt_t *ctx);
@@ -37,6 +35,3 @@ int dlt_loop_cleanup(tcpeditdlt_t *ctx);
 #ifdef __cplusplus
 }
 #endif
-
-#endif
-
