@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,16 +18,12 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "null.h"
+#include "dlt_utils.h"
+#include "tcpedit.h"
+#include "tcpedit_stub.h"
 #include <stdlib.h>
 #include <string.h>
-
-#include "tcpedit.h"
-#include "common.h"
-#include "tcpr.h"
-#include "dlt_utils.h"
-#include "tcpedit_stub.h"
-#include "null.h"
-
 #include <sys/socket.h> // PF_* values
 
 static char dlt_name[] = "null";
@@ -42,7 +38,7 @@ static uint16_t dlt_value = DLT_NULL;
  *
  * Note that ``host byte  order''  is  the  byte  order  of  the
  * machine on which the packets are captured, and the PF_ values
- * are for the OS of the machine on which the packets  are  captured;  
+ * are for the OS of the machine on which the packets  are  captured;
  * if  a live capture is being done, ``host byte order''
  * is the byte order of the machine capturing the  packets,  and
  * the  PF_  values are those of the OS of the machine capturing
@@ -62,7 +58,7 @@ static uint16_t dlt_value = DLT_NULL;
  * - Add the plugin to the context's plugin chain
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_null_register(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -73,16 +69,18 @@ dlt_null_register(tcpeditdlt_t *ctx)
 
     /* set what we provide & require */
     plugin->provides += PLUGIN_MASK_PROTO;
-    plugin->requires += 0;
+    plugin->
+        requires
+    += 0;
 
-     /* what is our DLT value? */
+    /* what is our DLT value? */
     plugin->dlt = dlt_value;
 
     /* set the prefix name of our plugin.  This is also used as the prefix for our options */
     plugin->name = safe_strdup(dlt_prefix);
 
-    /* 
-     * Point to our functions, note, you need a function for EVERY method.  
+    /*
+     * Point to our functions, note, you need a function for EVERY method.
      * Even if it is only an empty stub returning success.
      */
     plugin->plugin_init = dlt_null_init;
@@ -100,23 +98,22 @@ dlt_null_register(tcpeditdlt_t *ctx)
     return tcpedit_dlt_addplugin(ctx, plugin);
 }
 
- 
 /*
  * Initializer function.  This function is called only once, if and only if
- * this plugin will be utilized.  Remember, if you need to keep track of any state, 
+ * this plugin will be utilized.  Remember, if you need to keep track of any state,
  * store it in your plugin->config, not a global!
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_null_init(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
     assert(ctx);
-    
+
     if ((plugin = tcpedit_dlt_getplugin(ctx, dlt_value)) == NULL) {
         tcpedit_seterr(ctx->tcpedit, "Unable to initialize unregistered plugin %s", dlt_name);
         return TCPEDIT_ERROR;
-    }    
+    }
 
     return TCPEDIT_OK; /* success */
 }
@@ -126,7 +123,7 @@ dlt_null_init(tcpeditdlt_t *ctx)
  * Unless you allocated some memory in dlt_null_init(), this is just an stub.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_null_cleanup(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -152,7 +149,7 @@ dlt_null_cleanup(tcpeditdlt_t *ctx)
  * bit mask.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_null_parse_opts(tcpeditdlt_t *ctx)
 {
     assert(ctx);
@@ -171,8 +168,8 @@ dlt_null_parse_opts(tcpeditdlt_t *ctx)
  * - ctx->decoded_extra
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
-dlt_null_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_null_decode(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     int proto;
     assert(ctx);
@@ -191,13 +188,12 @@ dlt_null_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function to encode the layer 2 header back into the packet.
  * Returns: total packet len or TCPEDIT_ERROR
  */
-int 
-dlt_null_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen,
-        _U_ tcpr_dir_t dir)
+int
+dlt_null_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen, _U_ tcpr_dir_t dir)
 {
     assert(ctx);
     assert(packet);
-    
+
     tcpedit_seterr(ctx->tcpedit, "%s", "DLT_NULL and DLT_LOOP plugins do not support packet encoding");
     return TCPEDIT_ERROR;
 }
@@ -205,17 +201,17 @@ dlt_null_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen,
 /*
  * Function returns the Layer 3 protocol type of the given packet, or TCPEDIT_ERROR on error
  */
-int 
-dlt_null_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_null_proto(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     assert(ctx);
     assert(packet);
-    uint32_t *af_type; 
+    uint32_t *af_type;
     int protocol = 0;
 
     if (pktlen < 4)
         return TCPEDIT_ERROR;
-    
+
     /* PF_INET is always 2 but PF_INET6 varies based on platform, i.e
      * Linux - 10
      * NetBSD,OpenBSD,BSD/OS - 24
@@ -226,17 +222,15 @@ dlt_null_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
     af_type = (uint32_t *)packet;
     if (*af_type == PF_INET || SWAPLONG(*af_type) == PF_INET) {
         protocol = ETHERTYPE_IP;
-    } else if (*af_type == PF_INET6 || SWAPLONG(*af_type) == PF_INET6 ||
-               *af_type == 10 || SWAPLONG(*af_type) == 10 ||
-               *af_type == 24 || SWAPLONG(*af_type) == 24 ||
-               *af_type == 28 || SWAPLONG(*af_type) == 28 ||
+    } else if (*af_type == PF_INET6 || SWAPLONG(*af_type) == PF_INET6 || *af_type == 10 || SWAPLONG(*af_type) == 10 ||
+               *af_type == 24 || SWAPLONG(*af_type) == 24 || *af_type == 28 || SWAPLONG(*af_type) == 28 ||
                *af_type == 30 || SWAPLONG(*af_type) == 30) {
         protocol = ETHERTYPE_IP6;
     } else {
         tcpedit_seterr(ctx->tcpedit, "Unsupported DLT_NULL/DLT_LOOP PF_ type: 0x%04x", *af_type);
         return TCPEDIT_ERROR;
     }
-    
+
     return htons(protocol);
 }
 
@@ -244,7 +238,7 @@ dlt_null_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function returns a pointer to the layer 3 protocol header or NULL on error
  */
 u_char *
-dlt_null_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
+dlt_null_get_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen)
 {
     int l2len;
     assert(ctx);
@@ -265,29 +259,25 @@ dlt_null_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
  * like SPARC
  */
 u_char *
-dlt_null_merge_layer3(tcpeditdlt_t *ctx,
-                      u_char *packet,
-                      const int pktlen,
-                      u_char *ipv4_data,
-                      u_char *ipv6_data)
+dlt_null_merge_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen, u_char *ipv4_data, u_char *ipv6_data)
 {
     int l2len;
     assert(ctx);
     assert(packet);
     assert(ipv4_data || ipv6_data);
-    
+
     l2len = dlt_null_l2len(ctx, packet, pktlen);
     if (pktlen < l2len)
         return NULL;
-    
+
     return tcpedit_dlt_l3data_merge(ctx, packet, pktlen, ipv4_data ?: ipv6_data, l2len);
 }
 
-/* 
+/*
  * return the length of the L2 header of the current packet
  */
 int
-dlt_null_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+dlt_null_l2len(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     assert(ctx);
     assert(packet);
@@ -302,21 +292,18 @@ dlt_null_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 /*
  * return a static pointer to the source/destination MAC address
  * return NULL on error/address doesn't exist
- */    
+ */
 u_char *
-dlt_null_get_mac(tcpeditdlt_t *ctx, _U_ tcpeditdlt_mac_type_t mac,
-        const u_char *packet, _U_ const int pktlen)
+dlt_null_get_mac(tcpeditdlt_t *ctx, _U_ tcpeditdlt_mac_type_t mac, const u_char *packet, _U_ int pktlen)
 {
     assert(ctx);
     assert(packet);
 
-    return(NULL);
-
+    return (NULL);
 }
 
-tcpeditdlt_l2addr_type_t 
+tcpeditdlt_l2addr_type_t
 dlt_null_l2addr_type(void)
 {
     return NONE;
 }
-
