@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,16 +18,13 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <stdlib.h>
-#include <string.h>
-
-#include "tcpedit.h"
-#include "common.h"
-#include "tcpr.h"
-#include "dlt_utils.h"
-#include "tcpedit_stub.h"
 #include "radiotap.h"
 #include "../dlt_ieee80211/ieee80211.h"
+#include "dlt_utils.h"
+#include "tcpedit.h"
+#include "tcpedit_stub.h"
+#include <stdlib.h>
+#include <string.h>
 
 /* edit these variables to taste */
 static char dlt_name[] = "radiotap";
@@ -36,11 +33,11 @@ static uint16_t dlt_value = DLT_IEEE802_11_RADIO;
 
 /*
  * The Radiotap header plugin utilizes the 802.11 plugin internally to do all the work
- * we just eat the radiotap header itself and pass the resulting buffer to the ieee80211 
+ * we just eat the radiotap header itself and pass the resulting buffer to the ieee80211
  * plugin.
  */
 
-static u_char *dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen, const int radiolen);
+static u_char *dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet, int pktlen, int radiolen);
 
 /*
  * Function to register ourselves.  This function is always called, regardless
@@ -53,7 +50,7 @@ static u_char *dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet, c
  * - Add the plugin to the context's plugin chain
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_radiotap_register(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -64,16 +61,18 @@ dlt_radiotap_register(tcpeditdlt_t *ctx)
 
     /* we're a decoder only plugin, copy from ieee802.11 */
     plugin->provides += PLUGIN_MASK_PROTO + PLUGIN_MASK_SRCADDR + PLUGIN_MASK_DSTADDR;
-    plugin->requires += 0;
+    plugin->
+        requires
+    += 0;
 
-     /* what is our DLT value? */
+    /* what is our DLT value? */
     plugin->dlt = dlt_value;
 
     /* set the prefix name of our plugin.  This is also used as the prefix for our options */
     plugin->name = safe_strdup(dlt_name);
 
-    /* 
-     * Point to our functions, note, you need a function for EVERY method.  
+    /*
+     * Point to our functions, note, you need a function for EVERY method.
      * Even if it is only an empty stub returning success.
      */
     plugin->plugin_init = dlt_radiotap_init;
@@ -94,11 +93,11 @@ dlt_radiotap_register(tcpeditdlt_t *ctx)
 
 /*
  * Initializer function.  This function is called only once, if and only if
- * this plugin will be utilized.  Remember, if you need to keep track of any state, 
+ * this plugin will be utilized.  Remember, if you need to keep track of any state,
  * store it in your plugin->config, not a global!
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_radiotap_init(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -113,8 +112,7 @@ dlt_radiotap_init(tcpeditdlt_t *ctx)
     if (ctx->decoded_extra_size > 0) {
         if (ctx->decoded_extra_size < sizeof(radiotap_extra_t)) {
             ctx->decoded_extra_size = sizeof(radiotap_extra_t);
-            ctx->decoded_extra = safe_realloc(ctx->decoded_extra,
-                                              ctx->decoded_extra_size);
+            ctx->decoded_extra = safe_realloc(ctx->decoded_extra, ctx->decoded_extra_size);
         }
     } else {
         ctx->decoded_extra_size = sizeof(radiotap_extra_t);
@@ -133,7 +131,7 @@ dlt_radiotap_init(tcpeditdlt_t *ctx)
  * Unless you allocated some memory in dlt_radiotap_init(), this is just an stub.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_radiotap_cleanup(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -149,7 +147,7 @@ dlt_radiotap_cleanup(tcpeditdlt_t *ctx)
     safe_free(plugin->config);
     plugin->config = NULL;
     plugin->config_size = 0;
-        
+
     return TCPEDIT_OK; /* success */
 }
 
@@ -159,13 +157,13 @@ dlt_radiotap_cleanup(tcpeditdlt_t *ctx)
  * bit mask.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_radiotap_parse_opts(tcpeditdlt_t *ctx)
 {
     assert(ctx);
 
     /* we have none */
-    
+
     return TCPEDIT_OK; /* success */
 }
 
@@ -179,8 +177,8 @@ dlt_radiotap_parse_opts(tcpeditdlt_t *ctx)
  * - ctx->decoded_extra
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
-dlt_radiotap_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_radiotap_decode(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     int radiolen, rcode;
     u_char *data;
@@ -189,7 +187,7 @@ dlt_radiotap_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 
     if (pktlen < (int)sizeof(radiotap_hdr_t))
         return TCPEDIT_ERROR;
-    
+
     radiolen = dlt_radiotap_l2len(ctx, packet, pktlen);
     data = dlt_radiotap_get_80211(ctx, packet, pktlen, radiolen);
     if (!data)
@@ -197,7 +195,7 @@ dlt_radiotap_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 
     /* ieee80211 decoder fills out everything */
     rcode = dlt_ieee80211_decode(ctx, data, pktlen - radiolen);
-    
+
     /* need to override the ieee802.11 l2 length result */
     ctx->l2len = dlt_radiotap_80211_l2len(ctx, packet, pktlen);
     return (ctx->l2len > 0) ? rcode : TCPEDIT_ERROR;
@@ -207,13 +205,12 @@ dlt_radiotap_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function to encode the layer 2 header back into the packet.
  * Returns: total packet len or TCPEDIT_ERROR
  */
-int 
-dlt_radiotap_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen,
-        _U_ tcpr_dir_t dir)
+int
+dlt_radiotap_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen, _U_ tcpr_dir_t dir)
 {
     assert(ctx);
     assert(packet);
-    
+
     tcpedit_seterr(ctx->tcpedit, "%s", "DLT_IEEE802_11_RADIO plugin does not support packet encoding");
     return TCPEDIT_ERROR;
 }
@@ -223,8 +220,8 @@ dlt_radiotap_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen,
  * Make sure you return this in host byte order since all the comparisons will be
  * against the ETHERTYPE_* values which are oddly in host byte order.
  */
-int 
-dlt_radiotap_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_radiotap_proto(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     int radiolen;
     u_char *data;
@@ -246,14 +243,14 @@ dlt_radiotap_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function returns a pointer to the layer 3 protocol header or NULL on error
  */
 u_char *
-dlt_radiotap_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
+dlt_radiotap_get_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen)
 {
     int radiolen, l2len;
     u_char *data;
-    
+
     assert(ctx);
     assert(packet);
-    
+
     radiolen = dlt_radiotap_l2len(ctx, packet, pktlen);
     data = dlt_radiotap_get_80211(ctx, packet, pktlen, radiolen);
     l2len = dlt_ieee80211_l2len(ctx, data, pktlen - radiolen);
@@ -267,15 +264,11 @@ dlt_radiotap_get_layer3(tcpeditdlt_t *ctx, u_char *packet, const int pktlen)
  * like SPARC
  */
 u_char *
-dlt_radiotap_merge_layer3(tcpeditdlt_t *ctx,
-                          u_char *packet,
-                          const int pktlen,
-                          u_char *ipv4_data,
-                          u_char *ipv6_data)
+dlt_radiotap_merge_layer3(tcpeditdlt_t *ctx, u_char *packet, int pktlen, u_char *ipv4_data, u_char *ipv6_data)
 {
     int radiolen, l2len;
     u_char *data;
-    
+
     assert(ctx);
     assert(packet);
     assert(ipv4_data || ipv6_data);
@@ -289,13 +282,13 @@ dlt_radiotap_merge_layer3(tcpeditdlt_t *ctx,
 /*
  * return a static pointer to the source/destination MAC address
  * return NULL on error/address doesn't exist
- */    
+ */
 u_char *
-dlt_radiotap_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, const int pktlen)
+dlt_radiotap_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char *packet, int pktlen)
 {
     int radiolen;
     u_char *data;
-    
+
     assert(ctx);
     assert(packet);
 
@@ -308,13 +301,11 @@ dlt_radiotap_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_char
     return dlt_ieee80211_get_mac(ctx, mac, data, pktlen - radiolen);
 }
 
-
-
-/* 
+/*
  * return the length of the L2 header of the current packet
  */
 int
-dlt_radiotap_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+dlt_radiotap_l2len(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     uint16_t radiolen;
     assert(ctx);
@@ -329,15 +320,15 @@ dlt_radiotap_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
     return (int)radiolen;
 }
 
-/* 
+/*
  * return the length of the L2 header w/ 802.11 header of the current packet
  */
 int
-dlt_radiotap_80211_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+dlt_radiotap_80211_l2len(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     int radiolen, res;
     u_char *data;
-    
+
     radiolen = dlt_radiotap_l2len(ctx, packet, pktlen);
     if (radiolen == -1)
         return TCPEDIT_ERROR;
@@ -351,21 +342,20 @@ dlt_radiotap_80211_l2len(tcpeditdlt_t *ctx, const u_char *packet, const int pktl
     return radiolen;
 }
 
-tcpeditdlt_l2addr_type_t 
+tcpeditdlt_l2addr_type_t
 dlt_radiotap_l2addr_type(void)
 {
     /* FIXME: return the tcpeditdlt_l2addr_type_t value that this DLT uses */
     return ETHERNET;
 }
 
-/* 
+/*
  * returns a buffer to the 802.11 header in the packet.
  * This does an optimization of only doing a memcpy() once per packet
  * since we track which was the last packet # we copied.
  */
 static u_char *
-dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet,
-        const int pktlen, const int radiolen)
+dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet, int pktlen, int radiolen)
 {
     radiotap_extra_t *extra;
     static COUNTER lastpacket = 0;
@@ -374,9 +364,8 @@ dlt_radiotap_get_80211(tcpeditdlt_t *ctx, const u_char *packet,
         return NULL;
 
     extra = (radiotap_extra_t *)(ctx->decoded_extra);
-    if (pktlen >= radiolen &&
-            (size_t)(pktlen - radiolen) >= sizeof(extra->packet) &&
-            lastpacket != ctx->tcpedit->runtime.packetnum) {
+    if (pktlen >= radiolen && (size_t)(pktlen - radiolen) >= sizeof(extra->packet) &&
+        lastpacket != ctx->tcpedit->runtime.packetnum) {
         memcpy(extra->packet, &packet[radiolen], pktlen - radiolen);
         lastpacket = ctx->tcpedit->runtime.packetnum;
     }
