@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,16 +18,13 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "raw.h"
+#include "dlt_utils.h"
+#include "tcpedit.h"
+#include "tcpedit_stub.h"
 #include <stdlib.h>
 #include <string.h>
 
-#include "tcpedit.h"
-#include "common.h"
-#include "tcpr.h"
-#include "dlt_utils.h"
-#include "tcpedit_stub.h"
-#include "raw.h"
-
 static char dlt_name[] = "raw";
 static char _U_ dlt_prefix[] = "raw";
 static uint16_t dlt_value = DLT_RAW;
@@ -47,7 +44,7 @@ static uint16_t dlt_value = DLT_RAW;
  * - Add the plugin to the context's plugin chain
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_raw_register(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -59,14 +56,14 @@ dlt_raw_register(tcpeditdlt_t *ctx)
     /* set what we provide & require  */
     plugin->provides += PLUGIN_MASK_PROTO;
 
-     /* what is our DLT value? */
+    /* what is our DLT value? */
     plugin->dlt = dlt_value;
 
     /* set the prefix name of our plugin.  This is also used as the prefix for our options */
     plugin->name = safe_strdup(dlt_prefix);
 
-    /* 
-     * Point to our functions, note, you need a function for EVERY method.  
+    /*
+     * Point to our functions, note, you need a function for EVERY method.
      * Even if it is only an empty stub returning success.
      */
     plugin->plugin_init = dlt_raw_init;
@@ -80,19 +77,18 @@ dlt_raw_register(tcpeditdlt_t *ctx)
     plugin->plugin_get_layer3 = dlt_raw_get_layer3;
     plugin->plugin_merge_layer3 = dlt_raw_merge_layer3;
     plugin->plugin_get_mac = dlt_raw_get_mac;
-    
+
     /* add it to the available plugin list */
     return tcpedit_dlt_addplugin(ctx, plugin);
 }
 
- 
 /*
  * Initializer function.  This function is called only once, if and only if
- * this plugin will be utilized.  Remember, if you need to keep track of any state, 
+ * this plugin will be utilized.  Remember, if you need to keep track of any state,
  * store it in your plugin->config, not a global!
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_raw_init(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -107,8 +103,7 @@ dlt_raw_init(tcpeditdlt_t *ctx)
     if (ctx->decoded_extra_size > 0) {
         if (ctx->decoded_extra_size < sizeof(raw_extra_t)) {
             ctx->decoded_extra_size = sizeof(raw_extra_t);
-            ctx->decoded_extra = safe_realloc(ctx->decoded_extra,
-                                              ctx->decoded_extra_size);
+            ctx->decoded_extra = safe_realloc(ctx->decoded_extra, ctx->decoded_extra_size);
         }
     } else {
         ctx->decoded_extra_size = sizeof(raw_extra_t);
@@ -127,7 +122,7 @@ dlt_raw_init(tcpeditdlt_t *ctx)
  * Unless you allocated some memory in dlt_raw_init(), this is just an stub.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_raw_cleanup(tcpeditdlt_t *ctx)
 {
     tcpeditdlt_plugin_t *plugin;
@@ -153,7 +148,7 @@ dlt_raw_cleanup(tcpeditdlt_t *ctx)
  * bit mask.
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
+int
 dlt_raw_parse_opts(tcpeditdlt_t *ctx)
 {
     assert(ctx);
@@ -172,8 +167,8 @@ dlt_raw_parse_opts(tcpeditdlt_t *ctx)
  * - ctx->decoded_extra
  * Returns: TCPEDIT_ERROR | TCPEDIT_OK | TCPEDIT_WARN
  */
-int 
-dlt_raw_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_raw_decode(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     int proto;
     assert(ctx);
@@ -184,7 +179,7 @@ dlt_raw_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
 
     if ((proto = dlt_raw_proto(ctx, packet, pktlen)) == TCPEDIT_ERROR)
         return TCPEDIT_ERROR;
-        
+
     ctx->proto = (uint16_t)proto;
     ctx->l2len = 0;
 
@@ -195,27 +190,26 @@ dlt_raw_decode(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function to encode the layer 2 header back into the packet.
  * Returns: total packet len or TCPEDIT_ERROR
  */
-int 
-dlt_raw_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen,
-        _U_ tcpr_dir_t dir)
+int
+dlt_raw_encode(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen, _U_ tcpr_dir_t dir)
 {
     assert(ctx);
     assert(packet);
-    
+
     tcpedit_seterr(ctx->tcpedit, "%s", "DLT_RAW plugin does not support packet encoding");
-    return TCPEDIT_ERROR; 
+    return TCPEDIT_ERROR;
 }
 
 /*
  * Function returns the Layer 3 protocol type of the given packet, or TCPEDIT_ERROR on error
  */
-int 
-dlt_raw_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
+int
+dlt_raw_proto(tcpeditdlt_t *ctx, const u_char *packet, int pktlen)
 {
     struct tcpr_ipv4_hdr *iphdr;
     assert(ctx);
     assert(packet);
-    int protocol = 0;
+    int protocol;
 
     if (pktlen < (int)sizeof(*iphdr))
         return TCPEDIT_ERROR;
@@ -229,7 +223,7 @@ dlt_raw_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
         tcpedit_seterr(ctx->tcpedit, "%s", "Unsupported DLT_RAW packet: doesn't look like IPv4 or IPv6");
         return TCPEDIT_ERROR;
     }
-    
+
     return htons(protocol);
 }
 
@@ -237,11 +231,11 @@ dlt_raw_proto(tcpeditdlt_t *ctx, const u_char *packet, const int pktlen)
  * Function returns a pointer to the layer 3 protocol header or NULL on error
  */
 u_char *
-dlt_raw_get_layer3(tcpeditdlt_t *ctx, u_char *packet, _U_ const int pktlen)
+dlt_raw_get_layer3(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen)
 {
     assert(ctx);
     assert(packet);
-    
+
     /* raw has a zero byte header, so this is basically a non-op */
 
     return packet;
@@ -254,26 +248,22 @@ dlt_raw_get_layer3(tcpeditdlt_t *ctx, u_char *packet, _U_ const int pktlen)
  * like SPARC
  */
 u_char *
-dlt_raw_merge_layer3(tcpeditdlt_t *ctx,
-                     u_char *packet, _U_
-                     const int pktlen,
-                     u_char *ipv4_data,
-                     u_char *ipv6_data)
+dlt_raw_merge_layer3(tcpeditdlt_t *ctx, u_char *packet, _U_ int pktlen, u_char *ipv4_data, u_char *ipv6_data)
 {
     assert(ctx);
     assert(packet);
     assert(ipv4_data || ipv6_data);
-    
+
     /* raw has a zero byte header, so this is basically a non-op */
-    
+
     return packet;
 }
 
-/* 
+/*
  * return the length of the L2 header of the current packet
  */
 int
-dlt_raw_l2len(tcpeditdlt_t *ctx, const u_char *packet, _U_ const int pktlen)
+dlt_raw_l2len(tcpeditdlt_t *ctx, const u_char *packet, _U_ int pktlen)
 {
     assert(ctx);
     assert(packet);
@@ -284,20 +274,18 @@ dlt_raw_l2len(tcpeditdlt_t *ctx, const u_char *packet, _U_ const int pktlen)
 /*
  * return a static pointer to the source/destination MAC address
  * return NULL on error/address doesn't exist
- */    
+ */
 u_char *
-dlt_raw_get_mac(tcpeditdlt_t *ctx, _U_ tcpeditdlt_mac_type_t mac,
-        const u_char *packet, _U_ const int pktlen)
+dlt_raw_get_mac(tcpeditdlt_t *ctx, _U_ tcpeditdlt_mac_type_t mac, const u_char *packet, _U_ int pktlen)
 {
     assert(ctx);
     assert(packet);
 
-    return(NULL);
+    return (NULL);
 }
 
-tcpeditdlt_l2addr_type_t 
+tcpeditdlt_l2addr_type_t
 dlt_raw_l2addr_type(void)
 {
     return NONE;
 }
-
