@@ -18,8 +18,7 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _DLT_user_API_H_
-#define _DLT_user_API_H_
+#pragma once
 
 #include "tcpedit_types.h"
 #include "plugins_types.h"
@@ -45,7 +44,3 @@ int tcpedit_user_set_dlink(tcpedit_t *tcpedit, u_char *data, int datalen, tcpedi
 #ifdef __cplusplus
 }
 #endif
-
-
-#endif
-
