@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -31,24 +31,18 @@
  *  - Auto learning of CIDR block for servers (clients all other)
  */
 
-#include "config.h"
 #include "defines.h"
+#include "config.h"
 #include "common.h"
-
+#include "tcpprep_api.h"
+#include "tcpprep_opts.h"
+#include "tree.h"
+#include <errno.h>
+#include <regex.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <regex.h>
-#include <string.h>
 #include <unistd.h>
-#include <errno.h>
-
-#include "tcpprep.h"
-#include "tcpprep_api.h"
-#include "tcpprep_opts.h"
-#include "lib/tree.h"
-#include "tree.h"
-#include "lib/sll.h"
 
 /*
  * global variables
@@ -59,19 +53,17 @@ int debug = 0;
 
 tcpprep_t *tcpprep;
 int info = 0;
-char *ourregex = NULL;
 char *cidr = NULL;
 tcpr_data_tree_t treeroot;
 
 void print_comment(const char *);
 void print_info(const char *);
 void print_stats(const char *);
-static int check_ipv4_regex(const unsigned long ip);
+static int check_ipv4_regex(unsigned long ip);
 static int check_ipv6_regex(const struct tcpr_in6_addr *addr);
-static COUNTER process_raw_packets(pcap_t * pcap);
+static COUNTER process_raw_packets(pcap_t *pcap);
 static int check_dst_port(ipv4_hdr_t *ip_hdr, ipv6_hdr_t *ip6_hdr, int len);
 
-
 /*
  *  main()
  */
@@ -79,49 +71,56 @@ int
 main(int argc, char *argv[])
 {
     int out_file;
-    COUNTER totpackets = 0;
+    COUNTER totpackets;
     char errbuf[PCAP_ERRBUF_SIZE];
     tcpprep_opt_t *options;
- 
+
     tcpprep = tcpprep_init();
     options = tcpprep->options;
-    
+
     optionProcess(&tcpprepOptions, argc, argv);
     tcpprep_post_args(tcpprep, argc, argv);
 
     /* open the cache file */
-    if ((out_file = open(OPT_ARG(CACHEFILE), O_WRONLY | O_CREAT | O_TRUNC,
-            S_IREAD | S_IWRITE | S_IRGRP | S_IWGRP | S_IROTH)) == -1)
-        errx(-1, "Unable to open cache file %s for writing: %s", 
-            OPT_ARG(CACHEFILE), strerror(errno));
+    if ((out_file = open(OPT_ARG(CACHEFILE),
+                         O_WRONLY | O_CREAT | O_TRUNC,
+                         S_IREAD | S_IWRITE | S_IRGRP | S_IWGRP | S_IROTH)) == -1) {
+        tcpprep_close(tcpprep);
+        errx(-1, "Unable to open cache file %s for writing: %s", OPT_ARG(CACHEFILE), strerror(errno));
+    }
 
-  readpcap:
+readpcap:
     /* open the pcap file */
-    if ((options->pcap = pcap_open_offline(OPT_ARG(PCAP), errbuf)) == NULL)
-        errx(-1, "Error opening file: %s", errbuf);
+    if ((options->pcap = pcap_open_offline(OPT_ARG(PCAP), errbuf)) == NULL) {
+        close(out_file);
+        tcpprep_close(tcpprep);
+        errx(-1, "Error opening libpcap: %s", errbuf);
+    }
 
 #ifdef HAVE_PCAP_SNAPSHOT
     if (pcap_snapshot(options->pcap) < 65535)
         warnx("%s was captured using a snaplen of %d bytes.  This may mean you have truncated packets.",
-                OPT_ARG(PCAP), pcap_snapshot(options->pcap));
+              OPT_ARG(PCAP),
+              pcap_snapshot(options->pcap));
 #endif
 
     /* make sure we support the DLT type */
-    switch(pcap_datalink(options->pcap)) {
-        case DLT_EN10MB:
-        case DLT_LINUX_SLL:
-        case DLT_RAW:
-        case DLT_C_HDLC:
-        case DLT_JUNIPER_ETHER:
-        case DLT_PPP_SERIAL:
-            break; /* do nothing because all is good */
-        default:
-            errx(-1, "Unsupported pcap DLT type: 0x%x", pcap_datalink(options->pcap));
+    switch (pcap_datalink(options->pcap)) {
+    case DLT_EN10MB:
+    case DLT_LINUX_SLL:
+    case DLT_RAW:
+    case DLT_C_HDLC:
+    case DLT_JUNIPER_ETHER:
+    case DLT_PPP_SERIAL:
+        break; /* do nothing because all is good */
+    default:
+        errx(-1, "Unsupported pcap DLT type: 0x%x", pcap_datalink(options->pcap));
     }
 
     /* Can only split based on MAC address for ethernet */
-    if ((pcap_datalink(options->pcap) != DLT_EN10MB) &&
-        (options->mode == MAC_MODE)) {
+    if ((pcap_datalink(options->pcap) != DLT_EN10MB) && (options->mode == MAC_MODE)) {
+        close(out_file);
+        tcpprep_close(tcpprep);
         err(-1, "MAC mode splitting is only supported by DLT_EN10MB packet captures.");
     }
 
@@ -133,8 +132,10 @@ main(int argc, char *argv[])
 
     /* do we apply a bpf filter? */
     if (options->bpf.filter != NULL) {
-        if (pcap_compile(options->pcap, &options->bpf.program, options->bpf.filter,
-                         options->bpf.optimize, 0) != 0) {
+        if (pcap_compile(options->pcap, &options->bpf.program, options->bpf.filter, options->bpf.optimize, 0) != 0) {
+            close(out_file);
+            tcpprep_close(tcpprep);
+            return 0;
             errx(-1, "Error compiling BPF filter: %s", pcap_geterr(options->pcap));
         }
         pcap_setfilter(options->pcap, &options->bpf.program);
@@ -142,10 +143,13 @@ main(int argc, char *argv[])
     }
 
     if ((totpackets = process_raw_packets(options->pcap)) == 0) {
-        pcap_close(options->pcap);
+        close(out_file);
+        tcpprep_close(tcpprep);
         err(-1, "No packets were processed.  Filter too limiting?");
     }
+
     pcap_close(options->pcap);
+    options->pcap = NULL;
 
 #ifdef ENABLE_VERBOSE
     tcpdump_close(&tcpprep->tcpdump);
@@ -154,14 +158,13 @@ main(int argc, char *argv[])
     /* we need to process the pcap file twice in HASH/AUTO mode */
     if (options->mode == AUTO_MODE) {
         options->mode = options->automode;
-        if (options->mode == ROUTER_MODE) {  /* do we need to convert TREE->CIDR? */
+        if (options->mode == ROUTER_MODE) { /* do we need to convert TREE->CIDR? */
             if (info)
                 notice("Building network list from pre-cache...\n");
             if (!process_tree()) {
                 err(-1, "Error: unable to build a valid list of servers. Aborting.");
             }
-        }
-        else {
+        } else {
             /*
              * in bridge mode we need to calculate client/sever
              * manually since this is done automatically in
@@ -172,9 +175,9 @@ main(int argc, char *argv[])
 
         if (info)
             notice("Building cache file...\n");
-        /* 
+        /*
          * re-process files, but this time generate
-         * cache 
+         * cache
          */
         goto readpcap;
     }
@@ -184,24 +187,24 @@ main(int argc, char *argv[])
 #endif
 
     /* write cache data */
-    totpackets = write_cache(options->cachedata, out_file, totpackets, 
-        options->comment);
+    totpackets = write_cache(options->cachedata, out_file, totpackets, options->comment);
     if (info)
         notice("Done.\nCached " COUNTER_SPEC " packets.\n", totpackets);
 
     /* close cache file */
     close(out_file);
 
+    tcpprep_close(tcpprep);
+
     restore_stdin();
     return 0;
 }
 
-
 /**
  * checks the dst port to see if this is destined for a server port.
  * returns 1 for true, 0 for false
  */
-static int 
+static int
 check_dst_port(ipv4_hdr_t *ip_hdr, ipv6_hdr_t *ip6_hdr, int len)
 {
     tcp_hdr_t *tcp_hdr = NULL;
@@ -215,60 +218,62 @@ check_dst_port(ipv4_hdr_t *ip_hdr, ipv6_hdr_t *ip6_hdr, int len)
             return 0; /* not enough data in the packet to know */
 
         proto = ip_hdr->ip_p;
-        l4 = get_layer4_v4(ip_hdr, (u_char*)ip_hdr + len);
+        l4 = get_layer4_v4(ip_hdr, (u_char *)ip_hdr + len);
     } else if (ip6_hdr) {
         if (len < (TCPR_IPV6_H + 4))
             return 0; /* not enough data in the packet to know */
 
-        proto = get_ipv6_l4proto(ip6_hdr, (u_char*)ip6_hdr + len);
+        proto = get_ipv6_l4proto(ip6_hdr, (u_char *)ip6_hdr + len);
         dbgx(3, "Our layer4 proto is 0x%hhu", proto);
-        if ((l4 = get_layer4_v6(ip6_hdr, (u_char*)ip6_hdr + len)) == NULL)
+        if ((l4 = get_layer4_v6(ip6_hdr, (u_char *)ip6_hdr + len)) == NULL)
             return 0;
 
-        dbgx(3, "Found proto %u at offset %p.  base %p (%p)", proto, (void *)l4, (void *)ip6_hdr, (void*)(l4 - (u_char *)ip6_hdr));
+        dbgx(3,
+             "Found proto %u at offset %p.  base %p (%p)",
+             proto,
+             (void *)l4,
+             (void *)ip6_hdr,
+             (void *)(l4 - (u_char *)ip6_hdr));
     } else {
         assert(0);
     }
 
     dbg(3, "Checking the destination port...");
 
-    switch(proto) {
-        case IPPROTO_TCP:
-            tcp_hdr = (tcp_hdr_t *)l4;
+    switch (proto) {
+    case IPPROTO_TCP:
+        tcp_hdr = (tcp_hdr_t *)l4;
 
-            /* is a service? */
-            if (options->services.tcp[ntohs(tcp_hdr->th_dport)]) {
-                dbgx(1, "TCP packet is destined for a server port: %d", ntohs(tcp_hdr->th_dport));
-                return 1;
-            }
+        /* is a service? */
+        if (options->services.tcp[ntohs(tcp_hdr->th_dport)]) {
+            dbgx(1, "TCP packet is destined for a server port: %d", ntohs(tcp_hdr->th_dport));
+            return 1;
+        }
 
-            /* nope */
-            dbgx(1, "TCP packet is NOT destined for a server port: %d", ntohs(tcp_hdr->th_dport));
-            return 0;
-            break;
+        /* nope */
+        dbgx(1, "TCP packet is NOT destined for a server port: %d", ntohs(tcp_hdr->th_dport));
+        return 0;
 
-        case IPPROTO_UDP:
-            udp_hdr = (udp_hdr_t *)l4;
+    case IPPROTO_UDP:
+        udp_hdr = (udp_hdr_t *)l4;
 
-            /* is a service? */
-            if (options->services.udp[ntohs(udp_hdr->uh_dport)]) {
-                dbgx(1, "UDP packet is destined for a server port: %d", ntohs(udp_hdr->uh_dport));
-                return 1;
-            }
+        /* is a service? */
+        if (options->services.udp[ntohs(udp_hdr->uh_dport)]) {
+            dbgx(1, "UDP packet is destined for a server port: %d", ntohs(udp_hdr->uh_dport));
+            return 1;
+        }
 
-            /* nope */
-            dbgx(1, "UDP packet is NOT destined for a server port: %d", ntohs(udp_hdr->uh_dport));
-            return 0;
-            break;
+        /* nope */
+        dbgx(1, "UDP packet is NOT destined for a server port: %d", ntohs(udp_hdr->uh_dport));
+        return 0;
 
-        default:
-            /* not a TCP or UDP packet... return as non_ip */
-            dbg(1, "Packet isn't a UDP or TCP packet... no port to process.");
-            return options->nonip;
+    default:
+        /* not a TCP or UDP packet... return as non_ip */
+        dbg(1, "Packet isn't a UDP or TCP packet... no port to process.");
+        return options->nonip;
     }
 }
 
-
 /**
  * checks to see if an ip address matches a regex.  Returns 1 for true
  * 0 for false
@@ -282,8 +287,7 @@ check_ipv4_regex(const unsigned long ip)
     tcpprep_opt_t *options = tcpprep->options;
 
     memset(src_ip, '\0', sizeof(src_ip));
-    strlcpy((char *)src_ip, (char *)get_addr2name4(ip, RESOLVE),
-            sizeof(src_ip));
+    strlcpy((char *)src_ip, (char *)get_addr2name4(ip, RESOLVE), sizeof(src_ip));
     if (regexec(&options->preg, (char *)src_ip, nmatch, NULL, eflags) == 0) {
         return 1;
     } else {
@@ -300,8 +304,7 @@ check_ipv6_regex(const struct tcpr_in6_addr *addr)
     tcpprep_opt_t *options = tcpprep->options;
 
     memset(src_ip, '\0', sizeof(src_ip));
-    strlcpy((char *)src_ip, (char *)get_addr2name6(addr, RESOLVE),
-        sizeof(src_ip));
+    strlcpy((char *)src_ip, (char *)get_addr2name6(addr, RESOLVE), sizeof(src_ip));
     if (regexec(&options->preg, (char *)src_ip, nmatch, NULL, eflags) == 0) {
         return 1;
     } else {
@@ -314,7 +317,7 @@ check_ipv6_regex(const struct tcpr_in6_addr *addr)
  * the cache file.
  */
 static COUNTER
-process_raw_packets(pcap_t * pcap)
+process_raw_packets(pcap_t *pcap)
 {
     struct pcap_pkthdr pkthdr;
     const u_char *pktdata = NULL;
@@ -325,7 +328,7 @@ process_raw_packets(pcap_t * pcap)
     tcpprep_opt_t *options = tcpprep->options;
 
     assert(pcap);
-    
+
     ipbuff = safe_malloc(MAXPACKET);
 
     while ((pktdata = safe_pcap_next(pcap, &pkthdr)) != NULL) {
@@ -360,18 +363,17 @@ process_raw_packets(pcap_t * pcap)
          */
         if (options->mode != MAC_MODE) {
             dbg(3, "Looking for IPv4/v6 header in non-MAC mode");
-            
+
             /* get the IP header (if any) */
             buffptr = ipbuff;
-    
+
             /* first look for IPv4 */
-            if ((ip_hdr = (ipv4_hdr_t *)get_ipv4(pktdata, pkthdr.caplen, 
-                    pcap_datalink(pcap), &buffptr)) != NULL) {
+            if ((ip_hdr = (ipv4_hdr_t *)get_ipv4(pktdata, (int)pkthdr.caplen, pcap_datalink(pcap), &buffptr)) != NULL) {
                 dbg(2, "Packet is IPv4");
-            } else if ((ip6_hdr = (ipv6_hdr_t *)get_ipv6(pktdata, pkthdr.caplen,
-                    pcap_datalink(pcap), &buffptr)) != NULL) {
+            } else if ((ip6_hdr = (ipv6_hdr_t *)get_ipv6(pktdata, (int)pkthdr.caplen, pcap_datalink(pcap), &buffptr)) !=
+                       NULL) {
                 /* IPv6 */
-                dbg(2, "Packet is IPv6");    
+                dbg(2, "Packet is IPv6");
             } else {
                 /* we're something else... */
                 dbg(2, "Packet isn't IPv4/v6");
@@ -385,8 +387,8 @@ process_raw_packets(pcap_t * pcap)
                 /* go to next packet */
                 continue;
             }
-    
-            l2len = get_l2len(pktdata, pkthdr.caplen, pcap_datalink(pcap));
+
+            l2len = get_l2len(pktdata, (int)pkthdr.caplen, pcap_datalink(pcap));
             if (l2len < 0) {
                 /* go to next packet */
                 continue;
@@ -461,41 +463,29 @@ process_raw_packets(pcap_t * pcap)
             /* first run through in auto mode: create tree */
             if (options->automode != FIRST_MODE) {
                 if (ip_hdr) {
-                    add_tree_ipv4(ip_hdr->ip_src.s_addr,
-                                  pktdata,
-                                  pkthdr.caplen,
-                                  pcap_datalink(pcap));
+                    add_tree_ipv4(ip_hdr->ip_src.s_addr, pktdata, (int)pkthdr.caplen, pcap_datalink(pcap));
                 } else if (ip6_hdr) {
-                    add_tree_ipv6(&ip6_hdr->ip_src,
-                                  pktdata,
-                                  pkthdr.caplen,
-                                  pcap_datalink(pcap));
+                    add_tree_ipv6(&ip6_hdr->ip_src, pktdata, (int)pkthdr.caplen, pcap_datalink(pcap));
                 }
             } else {
                 if (ip_hdr) {
-                    add_tree_first_ipv4(pktdata,
-                                        pkthdr.caplen,
-                                        pcap_datalink(pcap));
+                    add_tree_first_ipv4(pktdata, (int)pkthdr.caplen, pcap_datalink(pcap));
                 } else if (ip6_hdr) {
-                    add_tree_first_ipv6(pktdata,
-                                        pkthdr.caplen,
-                                        pcap_datalink(pcap));
+                    add_tree_first_ipv6(pktdata, (int)pkthdr.caplen, pcap_datalink(pcap));
                 }
-            }  
+            }
             break;
 
         case ROUTER_MODE:
-            /* 
+            /*
              * second run through in auto mode: create route
              * based cache
              */
             dbg(2, "processing second pass of auto: router mode...");
             if (ip_hdr) {
-                add_cache(&options->cachedata, SEND,
-                    check_ip_tree(options->nonip, ip_hdr->ip_src.s_addr));
+                add_cache(&options->cachedata, SEND, check_ip_tree(options->nonip, ip_hdr->ip_src.s_addr));
             } else {
-                add_cache(&options->cachedata, SEND,
-                    check_ip6_tree(options->nonip, &ip6_hdr->ip_src));
+                add_cache(&options->cachedata, SEND, check_ip6_tree(options->nonip, &ip6_hdr->ip_src));
             }
             break;
 
@@ -506,41 +496,35 @@ process_raw_packets(pcap_t * pcap)
              */
             dbg(2, "processing second pass of auto: bridge mode...");
             if (ip_hdr) {
-                add_cache(&options->cachedata, SEND,
-                    check_ip_tree(DIR_UNKNOWN, ip_hdr->ip_src.s_addr));
+                add_cache(&options->cachedata, SEND, check_ip_tree(DIR_UNKNOWN, ip_hdr->ip_src.s_addr));
             } else {
-                add_cache(&options->cachedata, SEND,
-                    check_ip6_tree(DIR_UNKNOWN, &ip6_hdr->ip_src));
+                add_cache(&options->cachedata, SEND, check_ip6_tree(DIR_UNKNOWN, &ip6_hdr->ip_src));
             }
             break;
 
         case SERVER_MODE:
-            /* 
+            /*
              * second run through in auto mode: create bridge
              * where unknowns are servers
              */
             dbg(2, "processing second pass of auto: server mode...");
             if (ip_hdr) {
-                add_cache(&options->cachedata, SEND,
-                    check_ip_tree(DIR_SERVER, ip_hdr->ip_src.s_addr));
+                add_cache(&options->cachedata, SEND, check_ip_tree(DIR_SERVER, ip_hdr->ip_src.s_addr));
             } else {
-                add_cache(&options->cachedata, SEND,
-                    check_ip6_tree(DIR_SERVER, &ip6_hdr->ip_src));
+                add_cache(&options->cachedata, SEND, check_ip6_tree(DIR_SERVER, &ip6_hdr->ip_src));
             }
             break;
 
         case CLIENT_MODE:
-            /* 
+            /*
              * second run through in auto mode: create bridge
              * where unknowns are clients
              */
             dbg(2, "processing second pass of auto: client mode...");
             if (ip_hdr) {
-                add_cache(&options->cachedata, SEND,
-                    check_ip_tree(DIR_CLIENT, ip_hdr->ip_src.s_addr));
+                add_cache(&options->cachedata, SEND, check_ip_tree(DIR_CLIENT, ip_hdr->ip_src.s_addr));
             } else {
-                add_cache(&options->cachedata, SEND,
-                    check_ip6_tree(DIR_CLIENT, &ip6_hdr->ip_src));
+                add_cache(&options->cachedata, SEND, check_ip6_tree(DIR_CLIENT, &ip6_hdr->ip_src));
             }
             break;
 
@@ -549,8 +533,7 @@ process_raw_packets(pcap_t * pcap)
              * process ports based on their destination port
              */
             dbg(2, "processing port mode...");
-            add_cache(&options->cachedata, SEND,
-            check_dst_port(ip_hdr, ip6_hdr, (pkthdr.caplen - l2len)));
+            add_cache(&options->cachedata, SEND, check_dst_port(ip_hdr, ip6_hdr, (int)pkthdr.caplen - l2len));
             break;
 
         case FIRST_MODE:
@@ -560,14 +543,12 @@ process_raw_packets(pcap_t * pcap)
              */
             dbg(2, "processing second pass of auto: first packet mode...");
             if (ip_hdr) {
-                add_cache(&options->cachedata, SEND,
-                    check_ip_tree(DIR_UNKNOWN, ip_hdr->ip_src.s_addr));
+                add_cache(&options->cachedata, SEND, check_ip_tree(DIR_UNKNOWN, ip_hdr->ip_src.s_addr));
             } else {
-                add_cache(&options->cachedata, SEND,
-                    check_ip6_tree(DIR_UNKNOWN, &ip6_hdr->ip_src));
+                add_cache(&options->cachedata, SEND, check_ip6_tree(DIR_UNKNOWN, &ip6_hdr->ip_src));
             }
             break;
-            
+
         default:
             errx(-1, "Whoops!  What mode are we in anyways? %d", options->mode);
         }
@@ -582,7 +563,6 @@ process_raw_packets(pcap_t * pcap)
     return packetnum;
 }
 
-
 /**
  * print the tcpprep cache file comment
  */
@@ -591,7 +571,7 @@ print_comment(const char *file)
 {
     char *cachedata = NULL;
     char *comment = NULL;
-    COUNTER count = 0;
+    COUNTER count;
 
     count = read_cache(&cachedata, file, &comment);
     printf("tcpprep args: %s\n", comment);
@@ -608,14 +588,13 @@ print_info(const char *file)
 {
     char *cachedata = NULL;
     char *comment = NULL;
-    COUNTER count = 0, i;
+    COUNTER count, i;
 
     count = read_cache(&cachedata, file, &comment);
     if (count > 65535)
         exit(-1);
 
-    for (i = 1; i <= count; i ++) {
-        
+    for (i = 1; i <= count; i++) {
         switch (check_cache(cachedata, i)) {
         case TCPR_DIR_C2S:
             printf("Packet " COUNTER_SPEC " -> Primary\n", i);
@@ -628,9 +607,7 @@ print_info(const char *file)
             break;
         default:
             err(-1, "Invalid cachedata value!");
-            break;
         }
-
     }
     exit(0);
 }
@@ -643,24 +620,24 @@ print_stats(const char *file)
 {
     char *cachedata = NULL;
     char *comment = NULL;
-    COUNTER i, count = 0;
+    COUNTER i, count;
     COUNTER pri = 0, sec = 0, nosend = 0;
-    
+
     count = read_cache(&cachedata, file, &comment);
-    for (i = 1; i <= count; i ++) {
+    for (i = 1; i <= count; i++) {
         int cacheval = check_cache(cachedata, i);
         switch (cacheval) {
-            case TCPR_DIR_C2S:
-                pri ++;
-                break;
-            case TCPR_DIR_S2C:
-                sec ++;
-                break;
-            case TCPR_DIR_NOSEND:
-                nosend ++;
-                break;
-            default:
-                errx(-1, "Unknown cache value: %d", cacheval);
+        case TCPR_DIR_C2S:
+            pri++;
+            break;
+        case TCPR_DIR_S2C:
+            sec++;
+            break;
+        case TCPR_DIR_NOSEND:
+            nosend++;
+            break;
+        default:
+            errx(-1, "Unknown cache value: %d", cacheval);
         }
     }
     printf("Primary packets:\t" COUNTER_SPEC "\n", pri);
