@@ -4,9 +4,9 @@
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
  *   Copyright (c) 2013-2022 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
- *   The Tcpreplay Suite of tools is free software: you can redistribute it 
- *   and/or modify it under the terms of the GNU General Public License as 
- *   published by the Free Software Foundation, either version 3 of the 
+ *   The Tcpreplay Suite of tools is free software: you can redistribute it
+ *   and/or modify it under the terms of the GNU General Public License as
+ *   published by the Free Software Foundation, either version 3 of the
  *   License, or with the authors permission any later version.
  *
  *   The Tcpreplay Suite is distributed in the hope that it will be useful,
@@ -18,11 +18,10 @@
  *   along with the Tcpreplay Suite.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __TCPREWRITE_H__
-#define __TCPREWRITE_H__
+#pragma once
 
-#include "config.h"
 #include "defines.h"
+#include "config.h"
 #include "tcpedit/tcpedit.h"
 
 #ifdef ENABLE_DMALLOC
@@ -44,9 +43,9 @@ struct tcprewrite_opt_s {
     /* tcpprep cache data */
     COUNTER cache_packets;
     char *cachedata;
- 
+
     /* tcpprep cache file comment */
-    char *comment; 
+    char *comment;
 
 #ifdef ENABLE_VERBOSE
     /* tcpdump verbose printing */
@@ -57,8 +56,8 @@ struct tcprewrite_opt_s {
 #ifdef ENABLE_FRAGROUTE
     char *fragroute_args;
     fragroute_t *frag_ctx;
-#define FRAGROUTE_DIR_C2S  1
-#define FRAGROUTE_DIR_S2C  2
+#define FRAGROUTE_DIR_C2S 1
+#define FRAGROUTE_DIR_S2C 2
 #define FRAGROUTE_DIR_BOTH 4
     int fragroute_dir;
 #endif
@@ -66,5 +65,3 @@ struct tcprewrite_opt_s {
 };
 
 typedef struct tcprewrite_opt_s tcprewrite_opt_t;
-
-#endif /* __TCPREWRITE_H__ */
